@@ -56,8 +56,9 @@
 
 /**
  * \class Project
- * \brief Represents a project.
  * \ingroup core
+ * \brief Represents a project.
+ *
  * Project represents the root node of all objects created during the runtime of the program.
  * Manages also the undo stack.
  */
@@ -88,7 +89,7 @@ public:
 	}
 
 	QUndoStack undo_stack;
-	MdiWindowVisibility mdiWindowVisibility{Project::folderOnly};
+	MdiWindowVisibility mdiWindowVisibility{Project::MdiWindowVisibility::folderOnly};
 	QString fileName;
 	QString version;
 	QString author;
@@ -133,7 +134,7 @@ Project::~Project() {
 	//if the project is being closed, in Worksheet the scene items are being removed and the selection in the view can change.
 	//don't react on these changes since this can lead crashes (worksheet object is already in the destructor).
 	//->notify all worksheets about the project being closed.
-	for (auto* w : children<Worksheet>(AbstractAspect::Recursive))
+	for (auto* w : children<Worksheet>(ChildIndexFlag::Recursive))
 		w->setIsClosing();
 
 	d->undo_stack.clear();
@@ -181,10 +182,10 @@ void Project::setChanged(const bool value) {
 	if (isLoading())
 		return;
 
+	d->changed = value;
+
 	if (value)
 		emit changed();
-
-	d->changed = value;
 }
 
 void Project::setSuppressAspectAddedSignal(bool value) {
@@ -203,7 +204,7 @@ bool Project::hasChanged() const {
  * \brief Project::descriptionChanged
  * This function is called, when an object changes its name. When a column changed its name and wasn't connected before to the curve/column(formula) then
  * this is done in this function
- * \param column
+ * \param aspect
  */
 void Project::descriptionChanged(const AbstractAspect* aspect) {
 	if (isLoading())
@@ -216,7 +217,7 @@ void Project::descriptionChanged(const AbstractAspect* aspect) {
 
 		// When the column is created, it gets a random name and is eventually not connected to any curve.
 		// When changing the name it can match a curve and should than be connected to the curve.
-		QVector<XYCurve*> curves = children<XYCurve>(AbstractAspect::ChildIndexFlag::Recursive);
+		const QVector<XYCurve*>& curves = children<XYCurve>(ChildIndexFlag::Recursive);
 		QString columnPath = column->path();
 
 		// setXColumnPath must not be set, because if curve->column matches column, there already exist a
@@ -260,11 +261,11 @@ void Project::descriptionChanged(const AbstractAspect* aspect) {
 
 		}
 
-		QVector<Column*> columns = children<Column>(AbstractAspect::ChildIndexFlag::Recursive);
+		const QVector<Column*>& columns = children<Column>(ChildIndexFlag::Recursive);
 		for (auto* tempColumn : columns) {
-			const QStringList formulaVariableColumnsPath = tempColumn->formulaVariableColumnPaths();
+			const QStringList& formulaVariableColumnsPath = tempColumn->formulaVariableColumnPaths();
 			for (int i = 0; i < formulaVariableColumnsPath.count(); i++) {
-				if (formulaVariableColumnsPath[i] == columnPath)
+				if (formulaVariableColumnsPath.at(i) == columnPath)
 					tempColumn->setformulVariableColumn(i, const_cast<Column*>(static_cast<const Column*>(column)));
 			}
 		}
@@ -282,7 +283,7 @@ void Project::descriptionChanged(const AbstractAspect* aspect) {
  */
 void Project::aspectAddedSlot(const AbstractAspect* aspect) {
 
-	QVector<AbstractAspect*> _children = aspect->children(AspectType::Column, ChildIndexFlag::Recursive);
+	const QVector<AbstractAspect*>& _children = aspect->children(AspectType::Column, ChildIndexFlag::Recursive);
 	QVector<const AbstractColumn*> columns;
 	for (auto child : _children)
 		columns.append(static_cast<const AbstractColumn*>(child));
@@ -295,7 +296,7 @@ void Project::aspectAddedSlot(const AbstractAspect* aspect) {
 		return;
 
 	for (auto column : columns) {
-		QVector<XYCurve*> curves = children<XYCurve>(AbstractAspect::ChildIndexFlag::Recursive);
+		const QVector<XYCurve*>& curves = children<XYCurve>(ChildIndexFlag::Recursive);
 		QString columnPath = column->path();
 
 		for (auto* curve : curves) {
@@ -334,11 +335,11 @@ void Project::aspectAddedSlot(const AbstractAspect* aspect) {
 			}
 			curve->setUndoAware(true);
 		}
-		QVector<Column*> columns = children<Column>(AbstractAspect::ChildIndexFlag::Recursive);
+		const QVector<Column*>& columns = children<Column>(ChildIndexFlag::Recursive);
 		for (auto* tempColumn : columns) {
-			const QStringList formulaVariableColumnPaths = tempColumn->formulaVariableColumnPaths();
+			const QStringList& formulaVariableColumnPaths = tempColumn->formulaVariableColumnPaths();
 			for (int i = 0; i < formulaVariableColumnPaths.count(); i++) {
-				if (formulaVariableColumnPaths[i] == column->path())
+				if (formulaVariableColumnPaths.at(i) == column->path())
 					tempColumn->setformulVariableColumn(i, const_cast<Column*>(static_cast<const Column*>(column)));
 			}
 		}
@@ -399,7 +400,7 @@ void Project::save(const QPixmap& thumbnail, QXmlStreamWriter* writer) const {
  */
 void Project::save(QXmlStreamWriter* writer) const {
 	//save all children
-	for (auto* child : children<AbstractAspect>(IncludeHidden)) {
+	for (auto* child : children<AbstractAspect>(ChildIndexFlag::IncludeHidden)) {
 		writer->writeStartElement("child_aspect");
 		child->save(writer);
 		writer->writeEndElement();
@@ -524,7 +525,7 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 		//LiveDataSource:
 		//call finalizeLoad() to replace relative with absolute paths if required
 		//and to create columns during the initial read
-		QVector<LiveDataSource*> sources = children<LiveDataSource>(AbstractAspect::Recursive);
+		auto sources = children<LiveDataSource>(ChildIndexFlag::Recursive);
 		for (auto* source : sources) {
 			if (!source) continue;
 			source->finalizeLoad();
@@ -532,12 +533,12 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 
 		//everything is read now.
 		//restore the pointer to the data sets (columns) in xy-curves etc.
-		QVector<Column*> columns = children<Column>(AbstractAspect::Recursive);
+		auto columns = children<Column>(ChildIndexFlag::Recursive);
 
 		//xy-curves
 		// cannot be removed by the column observer, because it does not react
 		// on curve changes
-		QVector<XYCurve*> curves = children<XYCurve>(AbstractAspect::Recursive);
+		auto curves = children<XYCurve>(ChildIndexFlag::Recursive);
 		for (auto* curve : curves) {
 			if (!curve) continue;
 			curve->suppressRetransform(true);
@@ -565,7 +566,6 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 				RESTORE_COLUMN_POINTER(curve, xErrorMinusColumn, XErrorMinusColumn);
 				RESTORE_COLUMN_POINTER(curve, yErrorPlusColumn, YErrorPlusColumn);
 				RESTORE_COLUMN_POINTER(curve, yErrorMinusColumn, YErrorMinusColumn);
-				qDebug()<<"curve columns " << curve->xColumn() << "  " << curve->yColumn();
 			}
 			if (dynamic_cast<XYAnalysisCurve*>(curve))
 				RESTORE_POINTER(dynamic_cast<XYAnalysisCurve*>(curve), dataSourceCurve, DataSourceCurve, XYCurve, curves);
@@ -574,7 +574,7 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 		}
 
 		//axes
-		QVector<Axis*> axes = children<Axis>(AbstractAspect::Recursive);
+		auto axes = children<Axis>(ChildIndexFlag::Recursive);
 		for (auto* axis : axes) {
 			if (!axis) continue;
 			RESTORE_COLUMN_POINTER(axis, majorTicksColumn, MajorTicksColumn);
@@ -582,14 +582,14 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 		}
 
 		//histograms
-		QVector<Histogram*> hists = children<Histogram>(AbstractAspect::Recursive);
+		auto hists = children<Histogram>(ChildIndexFlag::Recursive);
 		for (auto* hist : hists) {
 			if (!hist) continue;
 			RESTORE_COLUMN_POINTER(hist, dataColumn, DataColumn);
 		}
 
 		//data picker curves
-		QVector<DatapickerCurve*> dataPickerCurves = children<DatapickerCurve>(AbstractAspect::Recursive);
+		auto dataPickerCurves = children<DatapickerCurve>(ChildIndexFlag::Recursive);
 		for (auto* dataPickerCurve : dataPickerCurves) {
 			if (!dataPickerCurve) continue;
 			RESTORE_COLUMN_POINTER(dataPickerCurve, posXColumn, PosXColumn);
@@ -622,7 +622,7 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 
 		//all data was read in spreadsheets:
 		//call CartesianPlot::retransform() to retransform the plots
-		for (auto* plot : children<CartesianPlot>(AbstractAspect::Recursive)) {
+		for (auto* plot : children<CartesianPlot>(ChildIndexFlag::Recursive)) {
 			plot->setIsLoading(false);
 			plot->retransform();
 		}
@@ -639,7 +639,7 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 				//determine the plots where the column is consumed
 				for (const auto* curve : curves) {
 					if (curve->xColumn() == column || curve->yColumn() == column) {
-						auto* plot = dynamic_cast<CartesianPlot*>(curve->parentAspect());
+						auto* plot = static_cast<CartesianPlot*>(curve->parentAspect());
 						if (plots.indexOf(plot) == -1) {
 							plots << plot;
 							plot->setSuppressDataChangedSignal(true);
@@ -653,10 +653,9 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 
 		//loop over all affected plots and retransform them
 		for (auto* plot : plots) {
-			plot->setSuppressDataChangedSignal(true);
+			plot->setSuppressDataChangedSignal(false);
 			plot->dataChanged();
 		}
-
 	}
 
 	emit loaded();
