@@ -36,6 +36,7 @@
 #include "backend/worksheet/Worksheet.h"
 #include "commonfrontend/datapicker/DatapickerImageView.h"
 #include "kdefrontend/worksheet/ExportWorksheetDialog.h"
+#include "backend/lib/trace.h"
 
 #include <QDesktopWidget>
 #include <QGraphicsScene>
@@ -58,11 +59,11 @@
  */
 DatapickerImage::DatapickerImage(const QString& name, bool loading) :
 	AbstractPart(name, AspectType::DatapickerImage),
-	foregroundBins( new int[ImageEditor::colorAttributeMax(Foreground) + 1]),
-	hueBins( new int[ImageEditor::colorAttributeMax(Hue) + 1]),
-	saturationBins( new int[ImageEditor::colorAttributeMax(Saturation) + 1]),
-	valueBins( new int[ImageEditor::colorAttributeMax(Value) + 1]),
-	intensityBins( new int[ImageEditor::colorAttributeMax(Intensity) + 1]),
+	foregroundBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Foreground) + 1]),
+	hueBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Hue) + 1]),
+	saturationBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Saturation) + 1]),
+	valueBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Value) + 1]),
+	intensityBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Intensity) + 1]),
 	d(new DatapickerImagePrivate(this)),
 	m_segments(new Segments(this)) {
 
@@ -89,11 +90,11 @@ void DatapickerImage::init() {
 	d->rotationAngle = group.readEntry("RotationAngle", 0.0);
 	d->minSegmentLength = group.readEntry("MinSegmentLength", 30);
 	d->pointSeparation = group.readEntry("PointSeparation", 30);
-	d->axisPoints.type = (DatapickerImage::GraphType) group.readEntry("GraphType", (int) DatapickerImage::Cartesian);
+	d->axisPoints.type = (DatapickerImage::GraphType) group.readEntry("GraphType", static_cast<int>(DatapickerImage::GraphType::Cartesian));
 	d->axisPoints.ternaryScale = group.readEntry("TernaryScale", 1);
 
 	//edit image settings
-	d->plotImageType = DatapickerImage::OriginalImage;
+	d->plotImageType = DatapickerImage::PlotImageType::OriginalImage;
 	d->settings.foregroundThresholdHigh = group.readEntry("ForegroundThresholdHigh", 90);
 	d->settings.foregroundThresholdLow = group.readEntry("ForegroundThresholdLow", 30);
 	d->settings.hueThresholdHigh = group.readEntry("HueThresholdHigh", 360);
@@ -106,15 +107,15 @@ void DatapickerImage::init() {
 	d->settings.valueThresholdLow = group.readEntry("ValueThresholdLow", 30);
 
 	// reference point symbol properties
-	d->pointStyle = (Symbol::Style)group.readEntry("PointStyle", (int)Symbol::Cross);
-	d->pointSize = group.readEntry("Size", Worksheet::convertToSceneUnits(7, Worksheet::Point));
+	d->pointStyle = (Symbol::Style)group.readEntry("PointStyle", (int)Symbol::Style::Cross);
+	d->pointSize = group.readEntry("Size", Worksheet::convertToSceneUnits(7, Worksheet::Unit::Point));
 	d->pointRotationAngle = group.readEntry("Rotation", 0.0);
 	d->pointOpacity = group.readEntry("Opacity", 1.0);
 	d->pointBrush.setStyle( (Qt::BrushStyle)group.readEntry("FillingStyle", (int)Qt::NoBrush) );
 	d->pointBrush.setColor( group.readEntry("FillingColor", QColor(Qt::black)) );
 	d->pointPen.setStyle( (Qt::PenStyle)group.readEntry("BorderStyle", (int)Qt::SolidLine) );
 	d->pointPen.setColor( group.readEntry("BorderColor", QColor(Qt::red)) );
-	d->pointPen.setWidthF( group.readEntry("BorderWidth", Worksheet::convertToSceneUnits(1, Worksheet::Point)) );
+	d->pointPen.setWidthF( group.readEntry("BorderWidth", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Point)) );
 	d->pointVisibility = group.readEntry("PointVisibility", true);
 }
 
@@ -214,7 +215,7 @@ QRectF DatapickerImage::pageRect() const {
 
 void DatapickerImage::setPlotImageType(const DatapickerImage::PlotImageType type) {
 	d->plotImageType = type;
-	if (d->plotImageType == DatapickerImage::ProcessedImage)
+	if (d->plotImageType == DatapickerImage::PlotImageType::ProcessedImage)
 		d->discretize();
 
 	emit requestUpdate();
@@ -316,8 +317,8 @@ void DatapickerImage::setPointVisibility(const bool on) {
 }
 
 void DatapickerImage::setPrinting(bool on) const {
-	QVector<DatapickerPoint*> childPoints = parentAspect()->children<DatapickerPoint>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
-	for (auto* point : childPoints)
+	auto points = parentAspect()->children<DatapickerPoint>(ChildIndexFlag::Recursive | ChildIndexFlag::IncludeHidden);
+	for (auto* point : points)
 		point->setPrinting(on);
 }
 
@@ -327,20 +328,20 @@ void DatapickerImage::setPlotPointsType(const PointsType pointsType) {
 
 	d->plotPointsType = pointsType;
 
-	if (pointsType == DatapickerImage::AxisPoints) {
+	if (pointsType == DatapickerImage::PointsType::AxisPoints) {
 		//clear image
-		int childCount = this->childCount<DatapickerPoint>(AbstractAspect::IncludeHidden);
-		if (childCount) {
+		auto points = children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
+		if (!points.isEmpty()) {
 			beginMacro(i18n("%1: remove all axis points", name()));
-			QVector<DatapickerPoint*> childrenPoints = children<DatapickerPoint>(AbstractAspect::IncludeHidden);
-			for (auto* point : childrenPoints)
+
+			for (auto* point : points)
 				point->remove();
 			endMacro();
 		}
 		m_segments->setSegmentsVisible(false);
-	} else if (pointsType == DatapickerImage::CurvePoints)
+	} else if (pointsType == DatapickerImage::PointsType::CurvePoints)
 		m_segments->setSegmentsVisible(false);
-	else if (pointsType == DatapickerImage::SegmentPoints) {
+	else if (pointsType == DatapickerImage::PointsType::SegmentPoints) {
 		d->makeSegments();
 		m_segments->setSegmentsVisible(true);
 	}
@@ -363,8 +364,8 @@ QString DatapickerImagePrivate::name() const {
 }
 
 void DatapickerImagePrivate::retransform() {
-	QVector<DatapickerPoint*> childrenPoints = q->children<DatapickerPoint>(AbstractAspect::IncludeHidden);
-	for (auto* point : childrenPoints)
+	auto points = q->children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
+	for (auto* point : points)
 		point->retransform();
 }
 
@@ -379,16 +380,16 @@ bool DatapickerImagePrivate::uploadImage(const QString& address) {
 		q->processedPlotImage = q->originalPlotImage;
 		q->background = ImageEditor::findBackgroundColor(&q->originalPlotImage);
 		//upload Histogram
-		ImageEditor::uploadHistogram(q->intensityBins, &q->originalPlotImage, q->background, DatapickerImage::Intensity);
-		ImageEditor::uploadHistogram(q->foregroundBins, &q->originalPlotImage, q->background, DatapickerImage::Foreground);
-		ImageEditor::uploadHistogram(q->hueBins, &q->originalPlotImage, q->background, DatapickerImage::Hue);
-		ImageEditor::uploadHistogram(q->saturationBins, &q->originalPlotImage, q->background, DatapickerImage::Saturation);
-		ImageEditor::uploadHistogram(q->valueBins, &q->originalPlotImage, q->background, DatapickerImage::Value);
+		ImageEditor::uploadHistogram(q->intensityBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Intensity);
+		ImageEditor::uploadHistogram(q->foregroundBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Foreground);
+		ImageEditor::uploadHistogram(q->hueBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Hue);
+		ImageEditor::uploadHistogram(q->saturationBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Saturation);
+		ImageEditor::uploadHistogram(q->valueBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Value);
 		discretize();
 
 		//resize the screen
-		double w = Worksheet::convertToSceneUnits(q->originalPlotImage.width(), Worksheet::Inch)/QApplication::desktop()->physicalDpiX();
-		double h = Worksheet::convertToSceneUnits(q->originalPlotImage.height(), Worksheet::Inch)/QApplication::desktop()->physicalDpiX();
+		double w = Worksheet::convertToSceneUnits(q->originalPlotImage.width(), Worksheet::Unit::Inch)/QApplication::desktop()->physicalDpiX();
+		double h = Worksheet::convertToSceneUnits(q->originalPlotImage.height(), Worksheet::Unit::Inch)/QApplication::desktop()->physicalDpiX();
 		m_scene->setSceneRect(0, 0, w, h);
 		q->isLoaded = true;
 	}
@@ -396,21 +397,23 @@ bool DatapickerImagePrivate::uploadImage(const QString& address) {
 }
 
 void DatapickerImagePrivate::discretize() {
-	if (plotImageType != DatapickerImage::ProcessedImage)
+	PERFTRACE("DatapickerImagePrivate::discretize()");
+	if (plotImageType != DatapickerImage::PlotImageType::ProcessedImage)
 		return;
 
 	ImageEditor::discretize(&q->processedPlotImage, &q->originalPlotImage, settings, q->background);
 
-	if (plotPointsType != DatapickerImage::SegmentPoints)
+	if (plotPointsType != DatapickerImage::PointsType::SegmentPoints)
 		emit q->requestUpdate();
 	else
 		makeSegments();
 }
 
 void DatapickerImagePrivate::makeSegments() {
-	if (plotPointsType != DatapickerImage::SegmentPoints)
+	if (plotPointsType != DatapickerImage::PointsType::SegmentPoints)
 		return;
 
+	PERFTRACE("DatapickerImagePrivate::makeSegments()");
 	q->m_segments->makeSegments(q->processedPlotImage);
 	q->m_segments->setSegmentsVisible(true);
 	emit q->requestUpdate();
@@ -433,9 +436,9 @@ void DatapickerImagePrivate::updateFileName() {
 		q->m_segments->setSegmentsVisible(false);
 	}
 
-	QVector<DatapickerPoint*> childPoints = q->parentAspect()->children<DatapickerPoint>(AbstractAspect::Recursive | AbstractAspect::IncludeHidden);
-	if (childPoints.count()) {
-		for (auto* point : childPoints)
+	auto points = q->parentAspect()->children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::Recursive | AbstractAspect::ChildIndexFlag::IncludeHidden);
+	if (!points.isEmpty()) {
+		for (auto* point : points)
 			point->remove();
 	}
 
@@ -456,11 +459,11 @@ void DatapickerImage::save(QXmlStreamWriter* writer) const {
 	//general properties
 	writer->writeStartElement( "general" );
 	writer->writeAttribute( "fileName", d->fileName );
-	writer->writeAttribute( "plotPointsType", QString::number(d->plotPointsType) );
+	writer->writeAttribute( "plotPointsType", QString::number(static_cast<int>(d->plotPointsType)) );
 	writer->writeEndElement();
 
 	writer->writeStartElement( "axisPoint" );
-	writer->writeAttribute( "graphType", QString::number(d->axisPoints.type) );
+	writer->writeAttribute( "graphType", QString::number(static_cast<int>(d->axisPoints.type)) );
 	writer->writeAttribute( "ternaryScale", QString::number(d->axisPoints.ternaryScale) );
 	writer->writeAttribute( "axisPointLogicalX1", QString::number(d->axisPoints.logicalPos[0].x()) );
 	writer->writeAttribute( "axisPointLogicalY1", QString::number(d->axisPoints.logicalPos[0].y()) );
@@ -481,7 +484,7 @@ void DatapickerImage::save(QXmlStreamWriter* writer) const {
 
 	//editor and segment settings
 	writer->writeStartElement( "editorSettings" );
-	writer->writeAttribute( "plotImageType", QString::number(d->plotImageType) );
+	writer->writeAttribute( "plotImageType", QString::number(static_cast<int>(d->plotImageType)) );
 	writer->writeAttribute( "rotationAngle", QString::number(d->rotationAngle) );
 	writer->writeAttribute( "minSegmentLength", QString::number(d->minSegmentLength) );
 	writer->writeAttribute( "pointSeparation", QString::number(d->pointSeparation) );
@@ -502,14 +505,14 @@ void DatapickerImage::save(QXmlStreamWriter* writer) const {
 	writer->writeAttribute( "pointRotationAngle", QString::number(d->pointRotationAngle) );
 	writer->writeAttribute( "pointOpacity", QString::number(d->pointOpacity) );
 	writer->writeAttribute( "pointSize", QString::number(d->pointSize) );
-	writer->writeAttribute( "pointStyle", QString::number(d->pointStyle) );
+	writer->writeAttribute( "pointStyle", QString::number(static_cast<int>(d->pointStyle)) );
 	writer->writeAttribute( "pointVisibility", QString::number(d->pointVisibility) );
 	WRITE_QBRUSH(d->pointBrush);
 	WRITE_QPEN(d->pointPen);
 	writer->writeEndElement();
 
 	//serialize all children
-	for (auto* child : children<AbstractAspect>(IncludeHidden))
+	for (auto* child : children<AbstractAspect>(ChildIndexFlag::IncludeHidden))
 		child->save(writer);
 
 	writer->writeEndElement();
