@@ -27,8 +27,6 @@ Copyright	: (C) 2018 Kovacs Ferencz (kferike98@gmail.com)
 ***************************************************************************/
 #include "backend/datasources/MQTTClient.h"
 
-#ifdef HAVE_MQTT
-
 #include "backend/datasources/MQTTSubscription.h"
 #include "backend/datasources/MQTTTopic.h"
 
@@ -54,8 +52,6 @@ Copyright	: (C) 2018 Kovacs Ferencz (kferike98@gmail.com)
 #include <QAction>
 #include <KLocalizedString>
 
-#include <QDebug>
-
 /*!
   \class MQTTClient
   \brief The MQTT Client connects to the broker set in ImportFileWidget.
@@ -91,7 +87,7 @@ MQTTClient::~MQTTClient() {
  * depending on the update type, periodically or on data changes, starts the timer.
  */
 void MQTTClient::ready() {
-	if (m_updateType == TimeInterval)
+	if (m_updateType == UpdateType::TimeInterval)
 		m_updateTimer->start(m_updateInterval);
 }
 
@@ -101,7 +97,7 @@ void MQTTClient::ready() {
 void MQTTClient::updateNow() {
 	m_updateTimer->stop();
 	read();
-	if ((m_updateType == TimeInterval) && !m_paused)
+	if ((m_updateType == UpdateType::TimeInterval) && !m_paused)
 		m_updateTimer->start(m_updateInterval);
 }
 
@@ -110,7 +106,7 @@ void MQTTClient::updateNow() {
  */
 void MQTTClient::continueReading() {
 	m_paused = false;
-	if (m_updateType == TimeInterval)
+	if (m_updateType == UpdateType::TimeInterval)
 		m_updateTimer->start(m_updateInterval);
 }
 
@@ -119,7 +115,7 @@ void MQTTClient::continueReading() {
  */
 void MQTTClient::pauseReading() {
 	m_paused = true;
-	if (m_updateType == TimeInterval)
+	if (m_updateType == UpdateType::TimeInterval)
 		m_updateTimer->stop();
 }
 
@@ -219,7 +215,7 @@ MQTTClient::ReadingType MQTTClient::readingType() const {
  * \param updatetype
  */
 void MQTTClient::setUpdateType(UpdateType updateType) {
-	if (updateType == NewData)
+	if (updateType == UpdateType::NewData)
 		m_updateTimer->stop();
 
 	m_updateType = updateType;
@@ -245,7 +241,7 @@ QIcon MQTTClient::icon() const {
  * \param host the hostname of the broker we want to connect to
  * \param port the port used by the broker
  */
-void MQTTClient::setMQTTClientHostPort(const QString& host, const quint16& port) {
+void MQTTClient::setMQTTClientHostPort(const QString& host, quint16 port) {
 	m_client->setHostname(host);
 	m_client->setPort(port);
 }
@@ -369,7 +365,7 @@ QVector<QString> MQTTClient::topicNames() const {
  * \param filter the name of the subscribed topic
  * \param qos the qos level of the subscription
  */
-void MQTTClient::addInitialMQTTSubscriptions(const QMqttTopicFilter& filter, const quint8& qos) {
+void MQTTClient::addInitialMQTTSubscriptions(const QMqttTopicFilter& filter, quint8 qos) {
 	m_subscribedTopicNameQoS[filter] = qos;
 }
 
@@ -393,7 +389,7 @@ void MQTTClient::addMQTTSubscription(const QString& topicName, quint8 QoS) {
 		QMqttSubscription* temp = m_client->subscribe(filter, QoS);
 
 		if (temp) {
-			qDebug()<<"Subscribe to: "<< temp->topic() << "  " << temp->qos();
+// 			qDebug()<<"Subscribe to: "<< temp->topic() << "  " << temp->qos();
 			m_subscriptions.push_back(temp->topic().filter());
 			m_subscribedTopicNameQoS[temp->topic().filter()] = temp->qos();
 
@@ -417,7 +413,7 @@ void MQTTClient::addMQTTSubscription(const QString& topicName, quint8 QoS) {
 			//If there are some inferior subscriptions, we have to deal with them
 			if (found) {
 				for (auto* inferiorSubscription : inferiorSubscriptions) {
-					qDebug()<<"Reparent topics of inferior subscription: "<< inferiorSubscription->subscriptionName();
+// 					qDebug()<<"Reparent topics of inferior subscription: "<< inferiorSubscription->subscriptionName();
 
 					//We have to reparent every topic of the inferior subscription, so no data is lost
 					QVector<MQTTTopic*> topics = inferiorSubscription->topics();
@@ -460,7 +456,7 @@ void MQTTClient::removeMQTTSubscription(const QString& subscriptionName) {
 		//unsubscribe from the topic
 		const QMqttTopicFilter filter{subscriptionName};
 		m_client->unsubscribe(filter);
-		qDebug()<<"Unsubscribe from: " << subscriptionName;
+// 		qDebug()<<"Unsubscribe from: " << subscriptionName;
 
 		//Remove every connected information
 		m_subscriptions.removeAll(subscriptionName);
@@ -507,7 +503,7 @@ void MQTTClient::addBeforeRemoveSubscription(const QString& topicName, quint8 Qo
 		QMqttSubscription* temp = m_client->subscribe(filter, QoS);
 		if (temp) {
 			//Add the MQTTSubscription and other connected data
-			qDebug()<<"Add subscription before remove: " << temp->topic() << "  " << temp->qos();
+// 			qDebug()<<"Add subscription before remove: " << temp->topic() << "  " << temp->qos();
 			m_subscriptions.push_back(temp->topic().filter());
 			m_subscribedTopicNameQoS[temp->topic().filter()] = temp->qos();
 
@@ -533,7 +529,7 @@ void MQTTClient::addBeforeRemoveSubscription(const QString& topicName, quint8 Qo
 				//Search for topics belonging to the superior(old) subscription
 				//which are also contained by the new subscription
 				QVector<MQTTTopic*> topics = superiorSubscription->topics();
-				qDebug()<< topics.size();
+// 				qDebug()<< topics.size();
 
 				QVector<MQTTTopic*> inferiorTopics;
 				for (auto* topic : topics) {
@@ -561,7 +557,7 @@ void MQTTClient::addBeforeRemoveSubscription(const QString& topicName, quint8 Qo
 void MQTTClient::reparentTopic(const QString& topicName, const QString& parentTopicName) {
 	//We can only reparent if the parent containd the topic
 	if (m_subscriptions.contains(parentTopicName) && m_topicNames.contains(topicName)) {
-		qDebug() << "Reparent " << topicName << " to " << parentTopicName;
+// 		qDebug() << "Reparent " << topicName << " to " << parentTopicName;
 		//search for the parent MQTTSubscription
 		bool found = false;
 		MQTTSubscription* superiorSubscription = nullptr;
@@ -575,7 +571,7 @@ void MQTTClient::reparentTopic(const QString& topicName, const QString& parentTo
 
 		if (found) {
 			//get every topic of the MQTTClient
-			QVector<MQTTTopic*> topics = children<MQTTTopic>(AbstractAspect::Recursive);
+			QVector<MQTTTopic*> topics = children<MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
 			//Search for the given topic among the MQTTTopics
 			for (auto* topic : topics) {
 				if (topicName == topic->topicName()) {
@@ -685,11 +681,11 @@ QString MQTTClient::checkCommonLevel(const QString& first, const QString& second
 			}
 		}
 	}
-	qDebug() << first << " " << second << " common topic: "<<commonTopic;
+// 	qDebug() << first << " " << second << " common topic: "<<commonTopic;
 	return commonTopic;
 }
 
-void MQTTClient::setWillSettings(MQTTWill settings) {
+void MQTTClient::setWillSettings(const MQTTWill& settings) {
 	m_MQTTWill = settings;
 }
 
@@ -721,7 +717,7 @@ bool MQTTClient::MQTTWillUse() const {
  * \param topic
  */
 void  MQTTClient::setWillTopic(const QString& topic) {
-	qDebug() << "Set will topic:" << topic;
+// 	qDebug() << "Set will topic:" << topic;
 	m_MQTTWill.willTopic = topic;
 }
 
@@ -800,7 +796,7 @@ QString MQTTClient::willOwnMessage() const {
  * \brief Updates the will message of the client
  */
 void MQTTClient::updateWillMessage() {
-	QVector<const MQTTTopic*> topics = children<const MQTTTopic>(AbstractAspect::Recursive);
+	QVector<const MQTTTopic*> topics = children<const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
 	const MQTTTopic* willTopic = nullptr;
 
 	//Search for the will topic
@@ -817,7 +813,7 @@ void MQTTClient::updateWillMessage() {
 		if (m_MQTTWill.enabled && (m_client->state() == QMqttClient::ClientState::Connected) ) {
 			//Disconnect only once (disconnecting may take a while)
 			if (!m_disconnectForWill) {
-				qDebug() << "Disconnecting from host in order to update will message";
+// 				qDebug() << "Disconnecting from host in order to update will message";
 				m_client->disconnectFromHost();
 				m_disconnectForWill = true;
 			}
@@ -827,19 +823,19 @@ void MQTTClient::updateWillMessage() {
 		//If client is disconnected we can update the settings
 		else if (m_MQTTWill.enabled && (m_client->state() == QMqttClient::ClientState::Disconnected) && m_disconnectForWill) {
 			m_client->setWillQoS(m_MQTTWill.willQoS);
-			qDebug()<<"Will QoS" << m_MQTTWill.willQoS;
+// 			qDebug()<<"Will QoS" << m_MQTTWill.willQoS;
 
 			m_client->setWillRetain(m_MQTTWill.willRetain);
-			qDebug()<<"Will retain" << m_MQTTWill.willRetain;
+// 			qDebug()<<"Will retain" << m_MQTTWill.willRetain;
 
 			m_client->setWillTopic(m_MQTTWill.willTopic);
-			qDebug()<<"Will Topic" << m_MQTTWill.willTopic;
+// 			qDebug()<<"Will Topic" << m_MQTTWill.willTopic;
 
 			//Set the will message according to m_willMessageType
 			switch (m_MQTTWill.willMessageType) {
 			case WillMessageType::OwnMessage:
 				m_client->setWillMessage(m_MQTTWill.willOwnMessage.toUtf8());
-				qDebug()<<"Will own message" << m_MQTTWill.willOwnMessage;
+// 				qDebug()<<"Will own message" << m_MQTTWill.willOwnMessage;
 				break;
 			case WillMessageType::Statistics: {
 				const auto asciiFilter = willTopic->filter();
@@ -855,13 +851,13 @@ void MQTTClient::updateWillMessage() {
 					else {
 						m_client->setWillMessage(QByteArray());
 					}
-					qDebug() << "Will statistics message: "<< QString(m_client->willMessage());
+// 					qDebug() << "Will statistics message: "<< QString(m_client->willMessage());
 				}
 				break;
 			}
 			case WillMessageType::LastMessage:
 				m_client->setWillMessage(m_MQTTWill.willLastMessage.toUtf8());
-				qDebug()<<"Will last message:\n" << m_MQTTWill.willLastMessage;
+// 				qDebug()<<"Will last message:\n" << m_MQTTWill.willLastMessage;
 				break;
 			default:
 				break;
@@ -869,7 +865,7 @@ void MQTTClient::updateWillMessage() {
 			m_disconnectForWill = false;
 			//Reconnect with the updated message
 			m_client->connectToHost();
-			qDebug()<< "Reconnect to host after updating will message";
+// 			qDebug()<< "Reconnect to host after updating will message";
 		}
 	}
 }
@@ -969,7 +965,7 @@ void MQTTClient::read() {
 		return;
 
 	if (!m_prepared) {
-		qDebug()<<"Connect";
+// 		qDebug()<<"Connect";
 		//connect to the broker
 		m_client->connectToHost();
 		m_prepared = true;
@@ -989,13 +985,13 @@ void MQTTClient::onMQTTConnect() {
 	if (m_client->error() == QMqttClient::NoError) {
 		//if this is the first connection (after setting the options in ImportFileWidget or loading saved project)
 		if (!m_MQTTFirstConnectEstablished) {
-			qDebug()<<"connection made in MQTTClient";
+// 			qDebug()<<"connection made in MQTTClient";
 
 			//Subscribe to initial or loaded topics
 			QMapIterator<QMqttTopicFilter, quint8> i(m_subscribedTopicNameQoS);
 			while (i.hasNext()) {
 				i.next();
-				qDebug()<<i.key();
+// 				qDebug()<<i.key();
 				QMqttSubscription *temp = m_client->subscribe(i.key(), i.value());
 				if (temp) {
 					//If we didn't load the MQTTClient from xml we have to add the MQTTSubscriptions
@@ -1019,17 +1015,18 @@ void MQTTClient::onMQTTConnect() {
 		}
 		//if there was already a connection made(happens after updating will message)
 		else {
-			qDebug() << "Start resubscribing after will message update";
+// 			qDebug() << "Start resubscribing after will message update";
 			//Only the client has to make the subscriptions again, every other connected data is still available
 			QMapIterator<QMqttTopicFilter, quint8> i(m_subscribedTopicNameQoS);
 			while (i.hasNext()) {
 				i.next();
 				QMqttSubscription* temp = m_client->subscribe(i.key(), i.value());
 				if (temp) {
-					qDebug()<<temp->topic()<<"  "<<temp->qos();
+// 					qDebug()<<temp->topic()<<"  "<<temp->qos();
 					connect(temp, &QMqttSubscription::messageReceived, this, &MQTTClient::MQTTSubscriptionMessageReceived);
-				} else
-					qDebug()<<"Couldn't subscribe after will update";
+				}
+// 				else
+// 					qDebug()<<"Couldn't subscribe after will update";
 			}
 		}
 	}
@@ -1082,7 +1079,7 @@ void MQTTClient::MQTTErrorChanged(QMqttClient::ClientError clientError) {
  */
 void MQTTClient::subscriptionLoaded(const QString &name) {
 	if (!name.isEmpty()) {
-		qDebug() << "Finished loading: " << name;
+// 		qDebug() << "Finished loading: " << name;
 		//Save information about the subscription
 		m_subscriptionsLoaded++;
 		m_subscriptions.push_back(name);
@@ -1123,14 +1120,14 @@ void MQTTClient::save(QXmlStreamWriter* writer) const {
 	//general
 	writer->writeStartElement("general");
 	writer->writeAttribute("subscriptionCount", QString::number(m_MQTTSubscriptions.size()));
-	writer->writeAttribute("updateType", QString::number(m_updateType));
-	writer->writeAttribute("readingType", QString::number(m_readingType));
+	writer->writeAttribute("updateType", QString::number(static_cast<int>(m_updateType)));
+	writer->writeAttribute("readingType", QString::number(static_cast<int>(m_readingType)));
 	writer->writeAttribute("keepValues", QString::number(m_keepNValues));
 
-	if (m_updateType == TimeInterval)
+	if (m_updateType == UpdateType::TimeInterval)
 		writer->writeAttribute("updateInterval", QString::number(m_updateInterval));
 
-	if (m_readingType != TillEnd)
+	if (m_readingType != ReadingType::TillEnd)
 		writer->writeAttribute("sampleSize", QString::number(m_sampleSize));
 
 	writer->writeAttribute("host", m_client->hostname());
@@ -1159,7 +1156,7 @@ void MQTTClient::save(QXmlStreamWriter* writer) const {
 	m_filter->save(writer);
 
 	//MQTTSubscription
-	for (auto* sub : children<MQTTSubscription>(IncludeHidden))
+	for (auto* sub : children<MQTTSubscription>(AbstractAspect::ChildIndexFlag::IncludeHidden))
 		sub->save(writer);
 
 	writer->writeEndElement(); // "MQTTClient"
@@ -1214,7 +1211,7 @@ bool MQTTClient::load(XmlStreamReader* reader, bool preview) {
 			else
 				m_readingType =  static_cast<ReadingType>(str.toInt());
 
-			if (m_updateType == TimeInterval) {
+			if (m_updateType == UpdateType::TimeInterval) {
 				str = attribs.value("updateInterval").toString();
 				if (str.isEmpty())
 					reader->raiseWarning(attributeWarning.arg("'updateInterval'"));
@@ -1222,7 +1219,7 @@ bool MQTTClient::load(XmlStreamReader* reader, bool preview) {
 					m_updateInterval = str.toInt();
 			}
 
-			if (m_readingType != TillEnd) {
+			if (m_readingType != ReadingType::TillEnd) {
 				str = attribs.value("sampleSize").toString();
 				if (str.isEmpty())
 					reader->raiseWarning(attributeWarning.arg("'sampleSize'"));
@@ -1355,4 +1352,4 @@ bool MQTTClient::load(XmlStreamReader* reader, bool preview) {
 
 	return !reader->hasError();
 }
-#endif
+
