@@ -6,7 +6,7 @@
     Copyright            : (C) 2006-2008 Tilman Benkert (thzs@gmx.net)
     Copyright            : (C) 2006-2009 Knut Franke (knut.franke@gmx.de)
     Copyright            : (C) 2012-2019 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2017 Stefan Gerlach (stefan.gerlach@uni.kn)
+    Copyright            : (C) 2017-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
  ***************************************************************************/
 
 /***************************************************************************
@@ -76,13 +76,15 @@ Spreadsheet::Spreadsheet(const QString& name, bool loading, AspectType type)
 	initializes the spreadsheet with the default number of columns and rows
 */
 void Spreadsheet::init() {
-	KConfigGroup group = KSharedConfig::openConfig()->group(QLatin1String("Spreadsheet"));
+	KConfig config;
+	KConfigGroup group = config.group(QLatin1String("Spreadsheet"));
+
 	const int columns = group.readEntry(QLatin1String("ColumnCount"), 2);
 	const int rows = group.readEntry(QLatin1String("RowCount"), 100);
 
 	for (int i = 0; i < columns; i++) {
-		Column* new_col = new Column(QString::number(i+1), AbstractColumn::Numeric);
-		new_col->setPlotDesignation(i == 0 ? AbstractColumn::X : AbstractColumn::Y);
+		Column* new_col = new Column(QString::number(i+1), AbstractColumn::ColumnMode::Numeric);
+		new_col->setPlotDesignation(i == 0 ? AbstractColumn::PlotDesignation::X : AbstractColumn::PlotDesignation::Y);
 		addChild(new_col);
 	}
 	setRowCount(rows);
@@ -121,6 +123,15 @@ bool Spreadsheet::printPreview() const {
 	return m_view->printPreview();
 }
 
+void Spreadsheet::updateHorizontalHeader() {
+	m_model->updateHorizontalHeader();
+}
+
+void Spreadsheet::updateLocale() {
+	for (auto* col : children<Column>())
+		col->updateLocale();
+}
+
 /*!
   Returns the maximum number of rows in the spreadsheet.
  */
@@ -138,7 +149,7 @@ void Spreadsheet::removeRows(int first, int count) {
 	if ( count < 1 || first < 0 || first+count > rowCount()) return;
 	WAIT_CURSOR;
 	beginMacro( i18np("%1: remove 1 row", "%1: remove %2 rows", name(), count) );
-	for (auto* col : children<Column>(IncludeHidden))
+	for (auto* col : children<Column>())
 		col->removeRows(first, count);
 	endMacro();
 	RESET_CURSOR;
@@ -148,7 +159,7 @@ void Spreadsheet::insertRows(int before, int count) {
 	if ( count < 1 || before < 0 || before > rowCount()) return;
 	WAIT_CURSOR;
 	beginMacro( i18np("%1: insert 1 row", "%1: insert %2 rows", name(), count) );
-	for (auto* col : children<Column>(IncludeHidden))
+	for (auto* col : children<Column>())
 		col->insertRows(before, count);
 	endMacro();
 	RESET_CURSOR;
@@ -193,7 +204,6 @@ Column* Spreadsheet::column(int index) const {
 	return child<Column>(index);
 }
 
-
 /*!
   Returns the column with the name \c name.
 */
@@ -235,8 +245,8 @@ void Spreadsheet::insertColumns(int before, int count) {
 	Column * before_col = column(before);
 	int rows = rowCount();
 	for (int i = 0; i < count; i++) {
-		Column * new_col = new Column(QString::number(i+1), AbstractColumn::Numeric);
-		new_col->setPlotDesignation(AbstractColumn::Y);
+		Column * new_col = new Column(QString::number(i+1), AbstractColumn::ColumnMode::Numeric);
+		new_col->setPlotDesignation(AbstractColumn::PlotDesignation::Y);
 		new_col->insertRows(0, rows);
 		insertChildBefore(new_col, before_col);
 	}
@@ -330,12 +340,12 @@ void Spreadsheet::copy(Spreadsheet* other) {
 */
 int Spreadsheet::colX(int col) {
 	for (int i = col-1; i >= 0; i--) {
-		if (column(i)->plotDesignation() == AbstractColumn::X)
+		if (column(i)->plotDesignation() == AbstractColumn::PlotDesignation::X)
 			return i;
 	}
 	int cols = columnCount();
 	for (int i = col+1; i < cols; i++) {
-		if (column(i)->plotDesignation() == AbstractColumn::X)
+		if (column(i)->plotDesignation() == AbstractColumn::PlotDesignation::X)
 			return i;
 	}
 	return -1;
@@ -347,25 +357,25 @@ int Spreadsheet::colX(int col) {
 int Spreadsheet::colY(int col) {
 	int cols = columnCount();
 
-	if (column(col)->plotDesignation() == AbstractColumn::XError ||
-	        column(col)->plotDesignation() == AbstractColumn::YError) {
+	if (column(col)->plotDesignation() == AbstractColumn::PlotDesignation::XError ||
+	        column(col)->plotDesignation() == AbstractColumn::PlotDesignation::YError) {
 		// look to the left first
 		for (int i = col-1; i >= 0; i--) {
-			if (column(i)->plotDesignation() == AbstractColumn::Y)
+			if (column(i)->plotDesignation() == AbstractColumn::PlotDesignation::Y)
 				return i;
 		}
 		for (int i = col+1; i < cols; i++) {
-			if (column(i)->plotDesignation() == AbstractColumn::Y)
+			if (column(i)->plotDesignation() == AbstractColumn::PlotDesignation::Y)
 				return i;
 		}
 	} else {
 		// look to the right first
 		for (int i = col+1; i < cols; i++) {
-			if (column(i)->plotDesignation() == AbstractColumn::Y)
+			if (column(i)->plotDesignation() == AbstractColumn::PlotDesignation::Y)
 				return i;
 		}
 		for (int i = col-1; i >= 0; i--) {
-			if (column(i)->plotDesignation() == AbstractColumn::Y)
+			if (column(i)->plotDesignation() == AbstractColumn::PlotDesignation::Y)
 				return i;
 		}
 	}
@@ -375,23 +385,32 @@ int Spreadsheet::colY(int col) {
 /*! Sorts the given list of column.
   If 'leading' is a null pointer, each column is sorted separately.
 */
-void Spreadsheet::sortColumns(Column* leading, QVector<Column*> cols, bool ascending) {
+void Spreadsheet::sortColumns(Column* leading, const QVector<Column*>& cols, bool ascending) {
+	DEBUG("Spreadsheet::sortColumns() : ascending = " << ascending)
 	if (cols.isEmpty()) return;
 
+
 	// the normal QPair comparison does not work properly with descending sorting
 	// therefore we use our own compare functions
+	// TODO: check this. a < b vs. a.first < b.first
 	class CompareFunctions {
 	public:
-		static bool doubleLess(const QPair<double, int>& a, const QPair<double, int>& b) {
+		static bool doubleLess(QPair<double, int> a, QPair<double, int> b) {
 			return a.first < b.first;
 		}
-		static bool doubleGreater(const QPair<double, int>& a, const QPair<double, int>& b) {
+		static bool doubleGreater(QPair<double, int> a, QPair<double, int> b) {
 			return a.first > b.first;
 		}
-		static bool integerLess(const QPair<int, int>& a, const QPair<int, int>& b) {
+		static bool integerLess(QPair<int, int> a, QPair<int, int> b) {
 			return a.first < b.first;
 		}
-		static bool integerGreater(const QPair<int, int>& a, const QPair<int, int>& b) {
+		static bool integerGreater(QPair<int, int> a, QPair<int, int> b) {
+			return a.first > b.first;
+		}
+		static bool bigIntLess(QPair<qint64, int> a, QPair<qint64, int> b) {
+			return a.first < b.first;
+		}
+		static bool bigIntGreater(QPair<qint64, int> a, QPair<qint64, int> b) {
 			return a.first > b.first;
 		}
 		static bool QStringLess(const QPair<QString, int>& a, const QPair<QString, int>& b) {
@@ -412,154 +431,177 @@ void Spreadsheet::sortColumns(Column* leading, QVector<Column*> cols, bool ascen
 	beginMacro(i18n("%1: sort columns", name()));
 
 	if (leading == nullptr) { // sort separately
+		DEBUG("	sort separately")
 		for (auto* col : cols) {
+			int rows = col->rowCount();
+			std::unique_ptr<Column> tempCol(new Column("temp", col->columnMode()));
+
 			switch (col->columnMode()) {
-			case AbstractColumn::Numeric: {
-					int rows = col->rowCount();
+			case AbstractColumn::ColumnMode::Numeric: {
 					QVector< QPair<double, int> > map;
 
-					for (int j = 0; j < rows; j++)
-						map.append(QPair<double, int>(col->valueAt(j), j));
+					for (int i = 0; i < rows; i++)
+						if (col->isValid(i))
+							map.append(QPair<double, int>(col->valueAt(i), i));
+					const int filledRows = map.size();
 
 					if (ascending)
 						std::stable_sort(map.begin(), map.end(), CompareFunctions::doubleLess);
 					else
 						std::stable_sort(map.begin(), map.end(), CompareFunctions::doubleGreater);
 
-					QVectorIterator< QPair<double, int> > it(map);
-					Column *temp_col = new Column("temp", col->columnMode());
-
-					int k = 0;
-					// put the values in the right order into temp_col
-					while (it.hasNext()) {
-						temp_col->copy(col, it.peekNext().second, k, 1);
-						temp_col->setMasked(col->isMasked(it.next().second));
-						k++;
+					// put the values in the right order into tempCol
+					for (int i = 0; i < filledRows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
 					}
-					// copy the sorted column
-					col->copy(temp_col, 0, 0, rows);
-					delete temp_col;
 					break;
 				}
-			case AbstractColumn::Integer: {
-					int rows = col->rowCount();
+			case AbstractColumn::ColumnMode::Integer: {
 					QVector< QPair<int, int> > map;
 
-					for (int j = 0; j < rows; j++)
-						map.append(QPair<int, int>(col->valueAt(j), j));
+					for (int i = 0; i < rows; i++)
+						map.append(QPair<int, int>(col->valueAt(i), i));
 
 					if (ascending)
-						std::stable_sort(map.begin(), map.end(), CompareFunctions::doubleLess);
+						std::stable_sort(map.begin(), map.end(), CompareFunctions::integerLess);
 					else
-						std::stable_sort(map.begin(), map.end(), CompareFunctions::doubleGreater);
+						std::stable_sort(map.begin(), map.end(), CompareFunctions::integerGreater);
 
-					QVectorIterator<QPair<int, int>> it(map);
-					Column* temp_col = new Column("temp", col->columnMode());
-
-					int k = 0;
-					// put the values in the right order into temp_col
-					while (it.hasNext()) {
-						temp_col->copy(col, it.peekNext().second, k, 1);
-						temp_col->setMasked(col->isMasked(it.next().second));
-						k++;
+					// put the values in the right order into tempCol
+					for (int i = 0; i < rows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
 					}
-					// copy the sorted column
-					col->copy(temp_col, 0, 0, rows);
-					delete temp_col;
 					break;
 				}
-			case AbstractColumn::Text: {
-					int rows = col->rowCount();
+			case AbstractColumn::ColumnMode::BigInt: {
+					QVector< QPair<qint64, int> > map;
+
+					for (int i = 0; i < rows; i++)
+						map.append(QPair<qint64, int>(col->valueAt(i), i));
+
+					if (ascending)
+						std::stable_sort(map.begin(), map.end(), CompareFunctions::bigIntLess);
+					else
+						std::stable_sort(map.begin(), map.end(), CompareFunctions::bigIntGreater);
+
+					// put the values in the right order into tempCol
+					for (int i = 0; i < rows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
+					}
+					break;
+				}
+			case AbstractColumn::ColumnMode::Text: {
 					QVector<QPair<QString, int>> map;
 
-					for (int j = 0; j < rows; j++)
-						map.append(QPair<QString, int>(col->textAt(j), j));
+					for (int i = 0; i < rows; i++)
+						if (!col->textAt(i).isEmpty())
+							map.append(QPair<QString, int>(col->textAt(i), i));
+					const int filledRows = map.size();
 
 					if (ascending)
 						std::stable_sort(map.begin(), map.end(), CompareFunctions::QStringLess);
 					else
 						std::stable_sort(map.begin(), map.end(), CompareFunctions::QStringGreater);
 
-					QVectorIterator< QPair<QString, int> > it(map);
-					Column* temp_col = new Column("temp", col->columnMode());
-
-					int k = 0;
-					// put the values in the right order into temp_col
-					while (it.hasNext()) {
-						temp_col->copy(col, it.peekNext().second, k, 1);
-						temp_col->setMasked(col->isMasked(it.next().second));
-						k++;
+					// put the values in the right order into tempCol
+					for (int i = 0; i < filledRows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
 					}
-					// copy the sorted column
-					col->copy(temp_col, 0, 0, rows);
-					delete temp_col;
 					break;
 				}
-			case AbstractColumn::DateTime:
-			case AbstractColumn::Month:
-			case AbstractColumn::Day: {
-					int rows = col->rowCount();
+			case AbstractColumn::ColumnMode::DateTime:
+			case AbstractColumn::ColumnMode::Month:
+			case AbstractColumn::ColumnMode::Day: {
 					QVector< QPair<QDateTime, int> > map;
 
-					for (int j = 0; j < rows; j++)
-						map.append(QPair<QDateTime, int>(col->dateTimeAt(j), j));
+					for (int i = 0; i < rows; i++)
+						if (col->isValid(i))
+							map.append(QPair<QDateTime, int>(col->dateTimeAt(i), i));
+					const int filledRows = map.size();
 
 					if (ascending)
 						std::stable_sort(map.begin(), map.end(), CompareFunctions::QDateTimeLess);
 					else
 						std::stable_sort(map.begin(), map.end(), CompareFunctions::QDateTimeGreater);
 
-					QVectorIterator< QPair<QDateTime, int> > it(map);
-					Column *temp_col = new Column("temp", col->columnMode());
-
-					int k = 0;
-					// put the values in the right order into temp_col
-					while (it.hasNext()) {
-						temp_col->copy(col, it.peekNext().second, k, 1);
-						temp_col->setMasked(col->isMasked(it.next().second));
-						k++;
+					// put the values in the right order into tempCol
+					for (int i = 0; i < filledRows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
 					}
-					// copy the sorted column
-					col->copy(temp_col, 0, 0, rows);
-					delete temp_col;
 					break;
 				}
 			}
+			// copy the sorted column
+			col->copy(tempCol.get(), 0, 0, rows);
 		}
 	} else { // sort with leading column
+		DEBUG("	sort with leading column")
+		int rows = leading->rowCount();
+
 		switch (leading->columnMode()) {
-		case AbstractColumn::Numeric: {
+		case AbstractColumn::ColumnMode::Numeric: {
 				QVector<QPair<double, int>> map;
-				int rows = leading->rowCount();
+				QVector<int> invalidIndex;
 
 				for (int i = 0; i < rows; i++)
-					map.append(QPair<double, int>(leading->valueAt(i), i));
+					if (leading->isValid(i))
+						map.append(QPair<double, int>(leading->valueAt(i), i));
+					else
+						invalidIndex << i;
+				const int filledRows = map.size();
+				const int invalidRows = invalidIndex.size();
 
 				if (ascending)
 					std::stable_sort(map.begin(), map.end(), CompareFunctions::doubleLess);
 				else
 					std::stable_sort(map.begin(), map.end(), CompareFunctions::doubleGreater);
-				QVectorIterator<QPair<double, int>> it(map);
 
 				for (auto* col : cols) {
-					Column *temp_col = new Column("temp", col->columnMode());
-					it.toFront();
-					int j = 0;
-					// put the values in the right order into temp_col
-					while (it.hasNext()) {
-						temp_col->copy(col, it.peekNext().second, j, 1);
-						temp_col->setMasked(col->isMasked(it.next().second));
-						j++;
+					auto columnMode = col->columnMode();
+					std::unique_ptr<Column> tempCol(new Column("temp", columnMode));
+					// put the values in correct order into tempCol
+					for (int i = 0; i < filledRows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
 					}
+
 					// copy the sorted column
-					col->copy(temp_col, 0, 0, rows);
-					delete temp_col;
+					if (col == leading)	// update all rows
+						col->copy(tempCol.get(), 0, 0, rows);
+					else {	// do not overwrite unused cols
+						std::unique_ptr<Column> tempInvalidCol(new Column("temp2", col->columnMode()));
+						for (int i = 0; i < invalidRows; i++) {
+							const int idx = invalidIndex.at(i);
+							//too slow: tempInvalidCol->copy(col, idx, i, 1);
+							tempInvalidCol->setFromColumn(i, col, idx);
+							tempInvalidCol->setMasked(col->isMasked(idx));
+						}
+						col->copy(tempCol.get(), 0, 0, filledRows);
+						col->copy(tempInvalidCol.get(), 0, filledRows, invalidRows);
+					}
 				}
 				break;
 			}
-		case AbstractColumn::Integer: {
+		case AbstractColumn::ColumnMode::Integer: {
+				//TODO: check if still working when invalid integer entries are supported
 				QVector<QPair<int, int>> map;
-				int rows = leading->rowCount();
 
 				for (int i = 0; i < rows; i++)
 					map.append(QPair<int, int>(leading->valueAt(i), i));
@@ -568,86 +610,139 @@ void Spreadsheet::sortColumns(Column* leading, QVector<Column*> cols, bool ascen
 					std::stable_sort(map.begin(), map.end(), CompareFunctions::integerLess);
 				else
 					std::stable_sort(map.begin(), map.end(), CompareFunctions::integerGreater);
-				QVectorIterator<QPair<int, int>> it(map);
 
 				for (auto* col : cols) {
-					Column *temp_col = new Column("temp", col->columnMode());
-					it.toFront();
-					int j = 0;
-					// put the values in the right order into temp_col
-					while (it.hasNext()) {
-						temp_col->copy(col, it.peekNext().second, j, 1);
-						temp_col->setMasked(col->isMasked(it.next().second));
-						j++;
+					std::unique_ptr<Column> tempCol(new Column("temp", col->columnMode()));
+					// put the values in the right order into tempCol
+					for (int i = 0; i < rows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
 					}
 					// copy the sorted column
-					col->copy(temp_col, 0, 0, rows);
-					delete temp_col;
+					col->copy(tempCol.get(), 0, 0, rows);
 				}
 				break;
 			}
-		case AbstractColumn::Text: {
-				QVector<QPair<QString, int>> map;
-				int rows = leading->rowCount();
+		case AbstractColumn::ColumnMode::BigInt: {
+				QVector<QPair<qint64, int>> map;
 
 				for (int i = 0; i < rows; i++)
-					map.append(QPair<QString, int>(leading->textAt(i), i));
+					map.append(QPair<qint64, int>(leading->valueAt(i), i));
+
+				if (ascending)
+					std::stable_sort(map.begin(), map.end(), CompareFunctions::bigIntLess);
+				else
+					std::stable_sort(map.begin(), map.end(), CompareFunctions::bigIntGreater);
+
+				for (auto* col : cols) {
+					std::unique_ptr<Column> tempCol(new Column("temp", col->columnMode()));
+					// put the values in the right order into tempCol
+					for (int i = 0; i < rows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
+					}
+					// copy the sorted column
+					col->copy(tempCol.get(), 0, 0, rows);
+				}
+				break;
+			}
+		case AbstractColumn::ColumnMode::Text: {
+				QVector<QPair<QString, int>> map;
+				QVector<int> emptyIndex;
+
+				for (int i = 0; i < rows; i++)
+					if (!leading->textAt(i).isEmpty())
+						map.append(QPair<QString, int>(leading->textAt(i), i));
+					else
+						emptyIndex << i;
+				//QDEBUG("	empty indices: " << emptyIndex)
+				const int filledRows = map.size();
+				const int emptyRows = emptyIndex.size();
 
 				if (ascending)
 					std::stable_sort(map.begin(), map.end(), CompareFunctions::QStringLess);
 				else
 					std::stable_sort(map.begin(), map.end(), CompareFunctions::QStringGreater);
-				QVectorIterator<QPair<QString, int>> it(map);
 
 				for (auto* col : cols) {
-					Column *temp_col = new Column("temp", col->columnMode());
-					it.toFront();
-					int j = 0;
-					// put the values in the right order into temp_col
-					while (it.hasNext()) {
-						temp_col->copy(col, it.peekNext().second, j, 1);
-						temp_col->setMasked(col->isMasked(it.next().second));
-						j++;
+					std::unique_ptr<Column> tempCol(new Column("temp", col->columnMode()));
+					// put the values in the right order into tempCol
+					for (int i = 0; i < filledRows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
 					}
+
 					// copy the sorted column
-					col->copy(temp_col, 0, 0, rows);
-					delete temp_col;
+					if (col == leading)	// update all rows
+						col->copy(tempCol.get(), 0, 0, rows);
+					else {	// do not overwrite unused cols
+						std::unique_ptr<Column> tempEmptyCol(new Column("temp2", col->columnMode()));
+						for (int i = 0; i < emptyRows; i++) {
+							const int idx = emptyIndex.at(i);
+							//too slow: tempEmptyCol->copy(col, idx, i, 1);
+							tempEmptyCol->setFromColumn(i, col, idx);
+							tempEmptyCol->setMasked(col->isMasked(idx));
+						}
+						col->copy(tempCol.get(), 0, 0, filledRows);
+						col->copy(tempEmptyCol.get(), 0, filledRows, emptyRows);
+					}
 				}
 				break;
 			}
-		case AbstractColumn::DateTime:
-		case AbstractColumn::Month:
-		case AbstractColumn::Day: {
+		case AbstractColumn::ColumnMode::DateTime:
+		case AbstractColumn::ColumnMode::Month:
+		case AbstractColumn::ColumnMode::Day: {
 				QVector<QPair<QDateTime, int>> map;
-				int rows = leading->rowCount();
+				QVector<int> invalidIndex;
 
 				for (int i = 0; i < rows; i++)
-					map.append(QPair<QDateTime, int>(leading->dateTimeAt(i), i));
+					if (leading->isValid(i))
+						map.append(QPair<QDateTime, int>(leading->dateTimeAt(i), i));
+					else
+						invalidIndex << i;
+				const int filledRows = map.size();
+				const int invalidRows = invalidIndex.size();
 
 				if (ascending)
 					std::stable_sort(map.begin(), map.end(), CompareFunctions::QDateTimeLess);
 				else
 					std::stable_sort(map.begin(), map.end(), CompareFunctions::QDateTimeGreater);
-				QVectorIterator<QPair<QDateTime, int>> it(map);
 
 				for (auto* col : cols) {
-					Column *temp_col = new Column("temp", col->columnMode());
-					it.toFront();
-					int j = 0;
-					// put the values in the right order into temp_col
-					while (it.hasNext()) {
-						temp_col->copy(col, it.peekNext().second, j, 1);
-						temp_col->setMasked(col->isMasked(it.next().second));
-						j++;
+					std::unique_ptr<Column> tempCol(new Column("temp", col->columnMode()));
+					// put the values in the right order into tempCol
+					for (int i = 0; i < filledRows; i++) {
+						int idx = map.at(i).second;
+						//too slow: tempCol->copy(col, idx, i, 1);
+						tempCol->setFromColumn(i, col, idx);
+						tempCol->setMasked(col->isMasked(idx));
 					}
 					// copy the sorted column
-					col->copy(temp_col, 0, 0, rows);
-					delete temp_col;
+					if (col == leading)	// update all rows
+						col->copy(tempCol.get(), 0, 0, rows);
+					else {	// do not overwrite unused cols
+						std::unique_ptr<Column> tempInvalidCol(new Column("temp2", col->columnMode()));
+						for (int i = 0; i < invalidRows; i++) {
+							const int idx = invalidIndex.at(i);
+							//too slow: tempInvalidCol->copy(col, idx, i, 1);
+							tempInvalidCol->setFromColumn(i, col, idx);
+							tempInvalidCol->setMasked(col->isMasked(idx));
+						}
+						col->copy(tempCol.get(), 0, 0, filledRows);
+						col->copy(tempInvalidCol.get(), 0, filledRows, invalidRows);
+					}
 				}
 				break;
 			}
 		}
 	}
+
 	endMacro();
 	RESET_CURSOR;
 } // end of sortColumns()
@@ -704,9 +799,15 @@ void Spreadsheet::setColumnSelectedInView(int index, bool selected) {
 	if (selected) {
 		emit childAspectSelectedInView(child<Column>(index));
 
-		//deselect the spreadsheet in the project explorer, if a child (column) was selected.
-		//prevents unwanted multiple selection with spreadsheet (if it was selected before).
-		emit childAspectDeselectedInView(this);
+		//deselect the spreadsheet in the project explorer, if a child (column) was selected
+		//and also all possible parents like folder, workbook, datapicker curve, datapicker
+		//to prevents unwanted multiple selection in the project explorer
+		//if one of the parents of the selected column was also selected before.
+		AbstractAspect* parent = this;
+		while (parent) {
+			emit childAspectDeselectedInView(parent);
+			parent = parent->parentAspect();
+		}
 	} else
 		emit childAspectDeselectedInView(child<Column>(index));
 }
@@ -723,7 +824,7 @@ void Spreadsheet::save(QXmlStreamWriter* writer) const {
 	writeCommentElement(writer);
 
 	//columns
-	for (auto* col : children<Column>(IncludeHidden))
+	for (auto* col : children<Column>(ChildIndexFlag::IncludeHidden))
 		col->save(writer);
 
 	writer->writeEndElement(); // "spreadsheet"
@@ -763,17 +864,6 @@ bool Spreadsheet::load(XmlStreamReader* reader, bool preview) {
 	return !reader->hasError();
 }
 
-void Spreadsheet::registerShortcuts() {
-	//TODO: when we create a live-data source we don't have the view here yet. why?
-	if (m_view)
-		m_view->registerShortcuts();
-}
-
-void Spreadsheet::unregisterShortcuts() {
-	if (m_view)
-		m_view->unregisterShortcuts();
-}
-
 //##############################################################################
 //########################  Data Import  #######################################
 //##############################################################################
@@ -795,7 +885,7 @@ int Spreadsheet::prepareImport(std::vector<void*>& dataContainer, AbstractFileFi
 	columnOffset = this->resize(importMode, colNameList, actualCols);
 
 	// resize the spreadsheet
-	if (importMode == AbstractFileFilter::Replace) {
+	if (importMode == AbstractFileFilter::ImportMode::Replace) {
 		clear();
 		setRowCount(actualRows);
 	}  else {
@@ -812,38 +902,44 @@ int Spreadsheet::prepareImport(std::vector<void*>& dataContainer, AbstractFileFi
 	for (int n = 0; n < actualCols; n++) {
 		// data() returns a void* which is a pointer to any data type (see ColumnPrivate.cpp)
 		Column* column = this->child<Column>(columnOffset+n);
-		DEBUG(" column " << n << " columnMode = " << columnMode[n]);
+		DEBUG(" column " << n << " columnMode = " << static_cast<int>(columnMode[n]));
 		column->setColumnModeFast(columnMode[n]);
 
 		//in the most cases the first imported column is meant to be used as x-data.
 		//Other columns provide mostly y-data or errors.
 		//TODO: this has to be configurable for the user in the import widget,
 		//it should be possible to specify x-error plot designation, etc.
-		AbstractColumn::PlotDesignation desig =  (n == 0) ? AbstractColumn::X : AbstractColumn::Y;
+		auto desig =  (n == 0) ? AbstractColumn::PlotDesignation::X : AbstractColumn::PlotDesignation::Y;
 		column->setPlotDesignation(desig);
 
 		switch (columnMode[n]) {
-		case AbstractColumn::Numeric: {
+		case AbstractColumn::ColumnMode::Numeric: {
 			auto* vector = static_cast<QVector<double>*>(column->data());
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 			break;
 		}
-		case AbstractColumn::Integer: {
+		case AbstractColumn::ColumnMode::Integer: {
 			auto* vector = static_cast<QVector<int>*>(column->data());
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 			break;
 		}
-		case AbstractColumn::Text: {
+		case AbstractColumn::ColumnMode::BigInt: {
+			auto* vector = static_cast<QVector<qint64>*>(column->data());
+			vector->resize(actualRows);
+			dataContainer[n] = static_cast<void*>(vector);
+			break;
+		}
+		case AbstractColumn::ColumnMode::Text: {
 			auto* vector = static_cast<QVector<QString>*>(column->data());
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 			break;
 		}
-		case AbstractColumn::Month:
-		case AbstractColumn::Day:
-		case AbstractColumn::DateTime: {
+		case AbstractColumn::ColumnMode::Month:
+		case AbstractColumn::ColumnMode::Day:
+		case AbstractColumn::ColumnMode::DateTime: {
 			auto* vector = static_cast<QVector<QDateTime>* >(column->data());
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
@@ -872,24 +968,25 @@ int Spreadsheet::resize(AbstractFileFilter::ImportMode mode, QStringList colName
 	int columnOffset = 0; //indexes the "start column" in the spreadsheet. Starting from this column the data will be imported.
 
 	Column* newColumn = nullptr;
-	if (mode == AbstractFileFilter::Append) {
+	if (mode == AbstractFileFilter::ImportMode::Append) {
 		columnOffset = childCount<Column>();
 		for (int n = 0; n < cols; n++ ) {
-			newColumn = new Column(colNameList.at(n), AbstractColumn::Numeric);
+			newColumn = new Column(colNameList.at(n), AbstractColumn::ColumnMode::Numeric);
 			newColumn->setUndoAware(false);
 			addChildFast(newColumn);
 		}
-	} else if (mode == AbstractFileFilter::Prepend) {
+	} else if (mode == AbstractFileFilter::ImportMode::Prepend) {
 		Column* firstColumn = child<Column>(0);
 		for (int n = 0; n < cols; n++ ) {
-			newColumn = new Column(colNameList.at(n), AbstractColumn::Numeric);
+			newColumn = new Column(colNameList.at(n), AbstractColumn::ColumnMode::Numeric);
 			newColumn->setUndoAware(false);
 			insertChildBeforeFast(newColumn, firstColumn);
 		}
-	} else if (mode == AbstractFileFilter::Replace) {
+	} else if (mode == AbstractFileFilter::ImportMode::Replace) {
 		//replace completely the previous content of the data source with the content to be imported.
 		int columns = childCount<Column>();
 
+
 		if (columns > cols) {
 			//there're more columns in the data source then required -> remove the superfluous columns
 			for (int i = 0; i < columns-cols; i++)
@@ -897,24 +994,20 @@ int Spreadsheet::resize(AbstractFileFilter::ImportMode mode, QStringList colName
 		} else {
 			//create additional columns if needed
 			for (int i = columns; i < cols; i++) {
-				newColumn = new Column(colNameList.at(i), AbstractColumn::Numeric);
+				newColumn = new Column(colNameList.at(i), AbstractColumn::ColumnMode::Numeric);
 				newColumn->setUndoAware(false);
 				addChildFast(newColumn);
 			}
 		}
 
-		//rename the columns that are already available and suppress the dataChanged signal for them
+		// 1. rename the columns that were already available
+		// 2. suppress the dataChanged signal for all columns
+		// 3. send aspectDescriptionChanged because otherwise the column
+		//    will not be connected again to the curves (project.cpp, descriptionChanged)
 		for (int i = 0; i < childCount<Column>(); i++) {
-			if (mode == AbstractFileFilter::Replace) {
-				child<Column>(i)->setSuppressDataChangedSignal(true);
-				emit child<Column>(i)->reset(child<Column>(i));
-			}
-
+			child<Column>(i)->setSuppressDataChangedSignal(true);
+			emit child<Column>(i)->reset(child<Column>(i));
 			child<Column>(i)->setName(colNameList.at(i));
-			// Force aspectDescriptionChanged is send, because otherwise the column
-			// will not connected again to the curves (project.cpp, descriptionChanged)
-			// it is not that expensive to call it twice (first time in setName, but
-			// only if the name changed)
 			child<Column>(i)->aspectDescriptionChanged(child<Column>(i));
 		}
 	}
@@ -927,7 +1020,7 @@ void Spreadsheet::finalizeImport(int columnOffset, int startColumn, int endColum
 
 	//determine the dependent plots
 	QVector<CartesianPlot*> plots;
-	if (importMode == AbstractFileFilter::Replace) {
+	if (importMode == AbstractFileFilter::ImportMode::Replace) {
 		for (int n = startColumn; n <= endColumn; n++) {
 			Column* column = this->column(columnOffset + n - startColumn);
 			column->addUsedInPlots(plots);
@@ -942,26 +1035,29 @@ void Spreadsheet::finalizeImport(int columnOffset, int startColumn, int endColum
 	const int rows = rowCount();
 	for (int n = startColumn; n <= endColumn; n++) {
 		Column* column = this->column(columnOffset + n - startColumn);
-		DEBUG("	column " << n << " of type " << column->columnMode());
+		DEBUG("	column " << n << " of type " << static_cast<int>(column->columnMode()));
 
 		QString comment;
 		switch (column->columnMode()) {
-		case AbstractColumn::Numeric:
+		case AbstractColumn::ColumnMode::Numeric:
 			comment = i18np("numerical data, %1 element", "numerical data, %1 elements", rows);
 			break;
-		case AbstractColumn::Integer:
+		case AbstractColumn::ColumnMode::Integer:
 			comment = i18np("integer data, %1 element", "integer data, %1 elements", rows);
 			break;
-		case AbstractColumn::Text:
+		case AbstractColumn::ColumnMode::BigInt:
+			comment = i18np("big integer data, %1 element", "big integer data, %1 elements", rows);
+			break;
+		case AbstractColumn::ColumnMode::Text:
 			comment = i18np("text data, %1 element", "text data, %1 elements", rows);
 			break;
-		case AbstractColumn::Month:
+		case AbstractColumn::ColumnMode::Month:
 			comment = i18np("month data, %1 element", "month data, %1 elements", rows);
 			break;
-		case AbstractColumn::Day:
+		case AbstractColumn::ColumnMode::Day:
 			comment = i18np("day data, %1 element", "day data, %1 elements", rows);
 			break;
-		case AbstractColumn::DateTime:
+		case AbstractColumn::ColumnMode::DateTime:
 			comment = i18np("date and time data, %1 element", "date and time data, %1 elements", rows);
 			// set same datetime format in column
 			auto* filter = static_cast<DateTime2StringFilter*>(column->outputFilter());
@@ -969,13 +1065,13 @@ void Spreadsheet::finalizeImport(int columnOffset, int startColumn, int endColum
 		}
 		column->setComment(comment);
 
-		if (importMode == AbstractFileFilter::Replace) {
+		if (importMode == AbstractFileFilter::ImportMode::Replace) {
 			column->setSuppressDataChangedSignal(false);
 			column->setChanged();
 		}
 	}
 
-	if (importMode == AbstractFileFilter::Replace) {
+	if (importMode == AbstractFileFilter::ImportMode::Replace) {
 		//retransform the dependent plots
 		for (auto* plot : plots) {
 			plot->setSuppressDataChangedSignal(false);
