@@ -36,14 +36,15 @@
 #include <QApplication>
 #include <QBuffer>
 #include <QDesktopWidget>
-#include <QPainter>
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
+#include <QKeyEvent>
 #include <QMenu>
+#include <QPainter>
 #include <QTextCharFormat>
 #include <QTextDocument>
 #include <QTextCursor>
-#include <QtConcurrentRun>
+#include <QtConcurrent/QtConcurrentRun>
 
 #include <QIcon>
 #include <KConfig>
@@ -57,10 +58,9 @@
  * The label is aligned relative to the specified position.
  * The position can be either specified by providing the x- and y- coordinates
  * in parent's coordinate system, or by specifying one of the predefined position
- * flags (\ca HorizontalPosition, \ca VerticalPosition).
+ * flags (\c HorizontalPosition, \c VerticalPosition).
  */
 
-
 TextLabel::TextLabel(const QString& name, Type type)
 	: WorksheetElement(name, AspectType::TextLabel), d_ptr(new TextLabelPrivate(this)), m_type(type) {
 
@@ -82,22 +82,22 @@ void TextLabel::init() {
 
 	QString groupName;
 	switch (m_type) {
-	case General:
+	case Type::General:
 		groupName = "TextLabel";
 		break;
-	case PlotTitle:
+	case Type::PlotTitle:
 		groupName = "PlotTitle";
 		break;
-	case AxisTitle:
+	case Type::AxisTitle:
 		groupName = "AxisTitle";
 		break;
-	case PlotLegendTitle:
+	case Type::PlotLegendTitle:
 		groupName = "PlotLegendTitle";
 		break;
 	}
 
 	const KConfig config;
-	DEBUG("	config has group \"" << groupName.toStdString() << "\": " << config.hasGroup(groupName));
+	DEBUG("	config has group \"" << STDSTRING(groupName) << "\": " << config.hasGroup(groupName));
 	// group is always valid if you call config.group(..;
 	KConfigGroup group;
 	if (config.hasGroup(groupName))
@@ -109,10 +109,13 @@ void TextLabel::init() {
 	QTextOption textOption;
 	textOption.setWrapMode(QTextOption::NoWrap);
 	d->staticText.setTextOption(textOption);
-	if (m_type != PlotTitle && m_type != PlotLegendTitle) {
-		d->position.horizontalPosition = TextLabel::hPositionCustom;
-		d->position.verticalPosition = TextLabel::vPositionCustom;
-		d->verticalAlignment = TextLabel::vAlignCenter;
+
+	if (m_type == Type::PlotTitle || m_type == Type::PlotLegendTitle) {
+		d->position.verticalPosition = WorksheetElement::VerticalPosition::Top;
+		d->verticalAlignment = WorksheetElement::VerticalAlignment::Bottom;
+	} else if (m_type == Type::AxisTitle) {
+		d->position.horizontalPosition = WorksheetElement::HorizontalPosition::Custom;
+		d->position.verticalPosition = WorksheetElement::VerticalPosition::Custom;
 	}
 
 	// read settings from config if group exists
@@ -137,8 +140,8 @@ void TextLabel::init() {
 		d->position.point.setY( group.readEntry("PositionYValue", d->position.point.y()) );
 		d->position.horizontalPosition = (HorizontalPosition) group.readEntry("PositionX", (int)d->position.horizontalPosition);
 		d->position.verticalPosition = (VerticalPosition) group.readEntry("PositionY", (int)d->position.verticalPosition);
-		d->horizontalAlignment = (TextLabel::HorizontalAlignment) group.readEntry("HorizontalAlignment", (int)d->horizontalAlignment);
-		d->verticalAlignment = (TextLabel::VerticalAlignment) group.readEntry("VerticalAlignment", (int)d->verticalAlignment);
+		d->horizontalAlignment = (WorksheetElement::HorizontalAlignment) group.readEntry("HorizontalAlignment", static_cast<int>(d->horizontalAlignment));
+		d->verticalAlignment = (WorksheetElement::VerticalAlignment) group.readEntry("VerticalAlignment", static_cast<int>(d->verticalAlignment));
 	}
 
 	DEBUG("CHECK: default/run time image resolution: " << d->teXImageResolution << '/' << QApplication::desktop()->physicalDpiX());
@@ -195,11 +198,11 @@ void TextLabel::handleResize(double horizontalRatio, double verticalRatio, bool
 	Returns an icon to be used in the project explorer.
 */
 QIcon TextLabel::icon() const{
-	return  QIcon::fromTheme("draw-text");
+	return QIcon::fromTheme("draw-text");
 }
 
 QMenu* TextLabel::createContextMenu() {
-	QMenu *menu = WorksheetElement::createContextMenu();
+	QMenu* menu = WorksheetElement::createContextMenu();
 	QAction* firstAction = menu->actions().at(1); //skip the first action because of the "title-action"
 
 	if (!visibilityAction) {
@@ -221,8 +224,8 @@ CLASS_SHARED_D_READER_IMPL(TextLabel, QColor, fontColor, fontColor);
 CLASS_SHARED_D_READER_IMPL(TextLabel, QColor, backgroundColor, backgroundColor);
 CLASS_SHARED_D_READER_IMPL(TextLabel, QFont, teXFont, teXFont);
 CLASS_SHARED_D_READER_IMPL(TextLabel, TextLabel::PositionWrapper, position, position);
-BASIC_SHARED_D_READER_IMPL(TextLabel, TextLabel::HorizontalAlignment, horizontalAlignment, horizontalAlignment);
-BASIC_SHARED_D_READER_IMPL(TextLabel, TextLabel::VerticalAlignment, verticalAlignment, verticalAlignment);
+BASIC_SHARED_D_READER_IMPL(TextLabel, WorksheetElement::HorizontalAlignment, horizontalAlignment, horizontalAlignment);
+BASIC_SHARED_D_READER_IMPL(TextLabel, WorksheetElement::VerticalAlignment, verticalAlignment, verticalAlignment);
 BASIC_SHARED_D_READER_IMPL(TextLabel, qreal, rotationAngle, rotationAngle);
 
 BASIC_SHARED_D_READER_IMPL(TextLabel, TextLabel::BorderShape, borderShape, borderShape)
@@ -263,6 +266,7 @@ void TextLabel::setPosition(const PositionWrapper& pos) {
 	Q_D(TextLabel);
 	if (pos.point != d->position.point || pos.horizontalPosition != d->position.horizontalPosition || pos.verticalPosition != d->position.verticalPosition)
 		exec(new TextLabelSetPositionCmd(d, pos, ki18n("%1: set position")));
+
 }
 
 /*!
@@ -282,9 +286,8 @@ void TextLabel::setPosition(QPointF point) {
  */
 void TextLabel::setPositionInvalid(bool invalid) {
 	Q_D(TextLabel);
-	if (invalid != d->positionInvalid) {
+	if (invalid != d->positionInvalid)
 		d->positionInvalid = invalid;
-	}
 }
 
 STD_SETTER_CMD_IMPL_F_S(TextLabel, SetRotationAngle, qreal, rotationAngle, recalcShapeAndBoundingRect);
@@ -295,13 +298,13 @@ void TextLabel::setRotationAngle(qreal angle) {
 }
 
 STD_SETTER_CMD_IMPL_F_S(TextLabel, SetHorizontalAlignment, TextLabel::HorizontalAlignment, horizontalAlignment, retransform);
-void TextLabel::setHorizontalAlignment(const TextLabel::HorizontalAlignment hAlign) {
+void TextLabel::setHorizontalAlignment(const WorksheetElement::HorizontalAlignment hAlign) {
 	Q_D(TextLabel);
 	if (hAlign != d->horizontalAlignment)
 		exec(new TextLabelSetHorizontalAlignmentCmd(d, hAlign, ki18n("%1: set horizontal alignment")));
 }
 
-STD_SETTER_CMD_IMPL_F_S(TextLabel, SetVerticalAlignment, TextLabel::VerticalAlignment, verticalAlignment, retransform);
+STD_SETTER_CMD_IMPL_F_S(TextLabel, SetVerticalAlignment, WorksheetElement::VerticalAlignment, verticalAlignment, retransform);
 void TextLabel::setVerticalAlignment(const TextLabel::VerticalAlignment vAlign) {
 	Q_D(TextLabel);
 	if (vAlign != d->verticalAlignment)
@@ -367,6 +370,7 @@ TextLabelPrivate::TextLabelPrivate(TextLabel* owner) : q(owner) {
 	setFlag(QGraphicsItem::ItemIsSelectable);
 	setFlag(QGraphicsItem::ItemIsMovable);
 	setFlag(QGraphicsItem::ItemSendsGeometryChanges);
+	setFlag(QGraphicsItem::ItemIsFocusable);
 	setAcceptHoverEvents(true);
 }
 
@@ -381,15 +385,15 @@ void TextLabelPrivate::retransform() {
 	if (suppressRetransform)
 		return;
 
-	if (position.horizontalPosition != TextLabel::hPositionCustom
-	        || position.verticalPosition != TextLabel::vPositionCustom)
+	if (position.horizontalPosition != WorksheetElement::HorizontalPosition::Custom
+	        || position.verticalPosition != WorksheetElement::VerticalPosition::Custom)
 		updatePosition();
 
-	float x = position.point.x();
-	float y = position.point.y();
+	double x = position.point.x();
+	double y = position.point.y();
 
 	//determine the size of the label in scene units.
-	float w, h;
+	double w, h;
 	if (textWrapper.teXUsed) {
 		//image size is in pixel, convert to scene units
 		w = teXImage.width()*teXImageScaleFactor;
@@ -404,25 +408,25 @@ void TextLabelPrivate::retransform() {
 	//depending on the alignment, calculate the new GraphicsItem's position in parent's coordinate system
 	QPointF itemPos;
 	switch (horizontalAlignment) {
-	case TextLabel::hAlignLeft:
+	case WorksheetElement::HorizontalAlignment::Left:
 		itemPos.setX(x - w/2);
 		break;
-	case TextLabel::hAlignCenter:
+	case WorksheetElement::HorizontalAlignment::Center:
 		itemPos.setX(x);
 		break;
-	case TextLabel::hAlignRight:
+	case WorksheetElement::HorizontalAlignment::Right:
 		itemPos.setX(x + w/2);
 		break;
 	}
 
 	switch (verticalAlignment) {
-	case TextLabel::vAlignTop:
+	case WorksheetElement::VerticalAlignment::Top:
 		itemPos.setY(y - h/2);
 		break;
-	case TextLabel::vAlignCenter:
+	case WorksheetElement::VerticalAlignment::Center:
 		itemPos.setY(y);
 		break;
-	case TextLabel::vAlignBottom:
+	case WorksheetElement::VerticalAlignment::Bottom:
 		itemPos.setY(y + h/2);
 		break;
 	}
@@ -437,6 +441,8 @@ void TextLabelPrivate::retransform() {
 	boundingRectangle.setHeight(h);
 
 	updateBorder();
+
+	emit q->changed();
 }
 
 /*!
@@ -455,21 +461,21 @@ void TextLabelPrivate::updatePosition() {
 		parentRect = scene()->sceneRect();
 	}
 
-	if (position.horizontalPosition != TextLabel::hPositionCustom) {
-		if (position.horizontalPosition == TextLabel::hPositionLeft)
+	if (position.horizontalPosition != WorksheetElement::HorizontalPosition::Custom) {
+		if (position.horizontalPosition == WorksheetElement::HorizontalPosition::Left)
 			position.point.setX( parentRect.x() );
-		else if (position.horizontalPosition == TextLabel::hPositionCenter)
+		else if (position.horizontalPosition == WorksheetElement::HorizontalPosition::Center)
 			position.point.setX( parentRect.x() + parentRect.width()/2 );
-		else if (position.horizontalPosition == TextLabel::hPositionRight)
+		else if (position.horizontalPosition == WorksheetElement::HorizontalPosition::Right)
 			position.point.setX( parentRect.x() + parentRect.width() );
 	}
 
-	if (position.verticalPosition != TextLabel::vPositionCustom) {
-		if (position.verticalPosition == TextLabel::vPositionTop)
+	if (position.verticalPosition != WorksheetElement::VerticalPosition::Custom) {
+		if (position.verticalPosition == WorksheetElement::VerticalPosition::Top)
 			position.point.setY( parentRect.y() );
-		else if (position.verticalPosition == TextLabel::vPositionCenter)
+		else if (position.verticalPosition == WorksheetElement::VerticalPosition::Center)
 			position.point.setY( parentRect.y() + parentRect.height()/2 );
-		else if (position.verticalPosition == TextLabel::vPositionBottom)
+		else if (position.verticalPosition == WorksheetElement::VerticalPosition::Bottom)
 			position.point.setY( parentRect.y() + parentRect.height() );
 	}
 
@@ -514,13 +520,12 @@ void TextLabelPrivate::updateTeXImage() {
 void TextLabelPrivate::updateBorder() {
 	borderShapePath = QPainterPath();
 	switch (borderShape) {
-	case (TextLabel::NoBorder):
+	case TextLabel::BorderShape::NoBorder:
 		break;
-	case (TextLabel::BorderShape::Rect): {
+	case TextLabel::BorderShape::Rect:
 		borderShapePath.addRect(boundingRectangle);
 		break;
-	}
-	case (TextLabel::BorderShape::Ellipse): {
+	case TextLabel::BorderShape::Ellipse: {
 		const double xs = boundingRectangle.x();
 		const double ys = boundingRectangle.y();
 		const double w = boundingRectangle.width();
@@ -528,7 +533,7 @@ void TextLabelPrivate::updateBorder() {
 		borderShapePath.addEllipse(xs  - 0.1 * w, ys - 0.1 * h, 1.2 * w,  1.2 * h);
 		break;
 	}
-	case (TextLabel::BorderShape::RoundSideRect): {
+	case TextLabel::BorderShape::RoundSideRect: {
 		const double xs = boundingRectangle.x();
 		const double ys = boundingRectangle.y();
 		const double w = boundingRectangle.width();
@@ -540,7 +545,7 @@ void TextLabelPrivate::updateBorder() {
 		borderShapePath.quadTo(xs - h/2, ys + h/2, xs, ys);
 		break;
 	}
-	case (TextLabel::BorderShape::RoundCornerRect): {
+	case TextLabel::BorderShape::RoundCornerRect: {
 		const double xs = boundingRectangle.x();
 		const double ys = boundingRectangle.y();
 		const double w = boundingRectangle.width();
@@ -555,9 +560,8 @@ void TextLabelPrivate::updateBorder() {
 		borderShapePath.lineTo(xs, ys + 0.2 * h);
 		borderShapePath.quadTo(xs, ys, xs + 0.2 * h, ys);
 		break;
-
 	}
-	case (TextLabel::BorderShape::InwardsRoundCornerRect): {
+	case TextLabel::BorderShape::InwardsRoundCornerRect: {
 		const double xs = boundingRectangle.x();
 		const double ys = boundingRectangle.y();
 		const double w = boundingRectangle.width();
@@ -573,7 +577,7 @@ void TextLabelPrivate::updateBorder() {
 		borderShapePath.quadTo(xs, ys, xs, ys - 0.3 * h);
 		break;
 	}
-	case (TextLabel::BorderShape::DentedBorderRect): {
+	case TextLabel::BorderShape::DentedBorderRect: {
 		const double xs = boundingRectangle.x();
 		const double ys = boundingRectangle.y();
 		const double w = boundingRectangle.width();
@@ -585,7 +589,7 @@ void TextLabelPrivate::updateBorder() {
 		borderShapePath.quadTo(xs, ys + h / 2, xs - 0.2 * h, ys - 0.2 * h);
 		break;
 	}
-	case (TextLabel::BorderShape::Cuboid): {
+	case TextLabel::BorderShape::Cuboid: {
 		const double xs = boundingRectangle.x();
 		const double ys = boundingRectangle.y();
 		const double w = boundingRectangle.width();
@@ -603,7 +607,7 @@ void TextLabelPrivate::updateBorder() {
 		borderShapePath.lineTo(xs + w + 0.3 * h, ys - 0.2 * h);
 		break;
 	}
-	case (TextLabel::BorderShape::UpPointingRectangle): {
+	case TextLabel::BorderShape::UpPointingRectangle: {
 		const double xs = boundingRectangle.x();
 		const double ys = boundingRectangle.y();
 		const double w = boundingRectangle.width();
@@ -686,7 +690,15 @@ void TextLabelPrivate::updateBorder() {
 
 bool TextLabelPrivate::swapVisible(bool on) {
 	bool oldValue = isVisible();
+
+	//When making a graphics item invisible, it gets deselected in the scene.
+	//In this case we don't want to deselect the item in the project explorer.
+	//We need to supress the deselection in the view.
+	auto* worksheet = static_cast<Worksheet*>(q->parent(AspectType::Worksheet));
+	worksheet->suppressSelectionChangedEvent(true);
 	setVisible(on);
+	worksheet->suppressSelectionChangedEvent(false);
+
 	emit q->changed();
 	emit q->visibleChanged(on);
 	return oldValue;
@@ -715,7 +727,7 @@ void TextLabelPrivate::recalcShapeAndBoundingRect() {
 	QMatrix matrix;
 	matrix.rotate(-rotationAngle);
 	labelShape = QPainterPath();
-	if (borderShape != TextLabel::NoBorder) {
+	if (borderShape != TextLabel::BorderShape::NoBorder) {
 		labelShape.addPath(WorksheetElement::shapeFromPath(borderShapePath, borderPen));
 		transformedBoundingRectangle = matrix.mapRect(labelShape.boundingRect());
 	} else {
@@ -724,8 +736,6 @@ void TextLabelPrivate::recalcShapeAndBoundingRect() {
 	}
 
 	labelShape = matrix.map(labelShape);
-
-	emit q->changed();
 }
 
 void TextLabelPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget) {
@@ -747,7 +757,9 @@ void TextLabelPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem*
 		if (boundingRect().width() != 0.0 &&  boundingRect().height() != 0.0)
 			painter->drawImage(boundingRect(), teXImage);
 	} else {
-		painter->setPen(fontColor);
+		// don't set fontColor to pen, because the color
+		// is already in the html code
+		//painter->setPen(fontColor);
 		painter->scale(scaleFactor, scaleFactor);
 		float w = staticText.size().width();
 		float h = staticText.size().height();
@@ -756,7 +768,7 @@ void TextLabelPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem*
 	painter->restore();
 
 	//draw the border
-	if (borderShape != TextLabel::NoBorder) {
+	if (borderShape != TextLabel::BorderShape::NoBorder) {
 		painter->save();
 		painter->rotate(-rotationAngle);
 		painter->setPen(borderPen);
@@ -784,8 +796,8 @@ QVariant TextLabelPrivate::itemChange(GraphicsItemChange change, const QVariant
 		//convert item's center point in parent's coordinates
 		TextLabel::PositionWrapper tempPosition;
 		tempPosition.point = positionFromItemPosition(value.toPointF());
-		tempPosition.horizontalPosition = TextLabel::hPositionCustom;
-		tempPosition.verticalPosition = TextLabel::vPositionCustom;
+		tempPosition.horizontalPosition = WorksheetElement::HorizontalPosition::Custom;
+		tempPosition.verticalPosition = WorksheetElement::VerticalPosition::Custom;
 
 		//emit the signals in order to notify the UI.
 		//we don't set the position related member variables during the mouse movements.
@@ -799,13 +811,13 @@ QVariant TextLabelPrivate::itemChange(GraphicsItemChange change, const QVariant
 void TextLabelPrivate::mouseReleaseEvent(QGraphicsSceneMouseEvent* event) {
 	//convert position of the item in parent coordinates to label's position
 	QPointF point = positionFromItemPosition(pos());
-	if (qAbs(point.x()-position.point.x())>20 && qAbs(point.y()-position.point.y())>20 ) {
+	if (point != position.point) {
 		//position was changed -> set the position related member variables
 		suppressRetransform = true;
 		TextLabel::PositionWrapper tempPosition;
 		tempPosition.point = point;
-		tempPosition.horizontalPosition = TextLabel::hPositionCustom;
-		tempPosition.verticalPosition = TextLabel::vPositionCustom;
+		tempPosition.horizontalPosition = WorksheetElement::HorizontalPosition::Custom;
+		tempPosition.verticalPosition = WorksheetElement::VerticalPosition::Custom;
 		q->setPosition(tempPosition);
 		suppressRetransform = false;
 	}
@@ -813,44 +825,75 @@ void TextLabelPrivate::mouseReleaseEvent(QGraphicsSceneMouseEvent* event) {
 	QGraphicsItem::mouseReleaseEvent(event);
 }
 
+void TextLabelPrivate::keyPressEvent(QKeyEvent* event) {
+	if (event->key() == Qt::Key_Left || event->key() == Qt::Key_Right
+		|| event->key() == Qt::Key_Up ||event->key() == Qt::Key_Down) {
+		const int delta = 5;
+		QPointF point = positionFromItemPosition(pos());
+		WorksheetElement::PositionWrapper tempPosition;
+
+		if (event->key() == Qt::Key_Left) {
+			point.setX(point.x() - delta);
+			tempPosition.horizontalPosition = WorksheetElement::HorizontalPosition::Custom;
+			tempPosition.verticalPosition = position.verticalPosition;
+		} else if (event->key() == Qt::Key_Right) {
+			point.setX(point.x() + delta);
+			tempPosition.horizontalPosition = WorksheetElement::HorizontalPosition::Custom;
+			tempPosition.verticalPosition = position.verticalPosition;
+		} else if (event->key() == Qt::Key_Up) {
+			point.setY(point.y() - delta);
+			tempPosition.horizontalPosition = position.horizontalPosition;
+			tempPosition.verticalPosition = WorksheetElement::VerticalPosition::Custom;
+		} else if (event->key() == Qt::Key_Down) {
+			point.setY(point.y() + delta);
+			tempPosition.horizontalPosition = position.horizontalPosition;
+			tempPosition.verticalPosition = WorksheetElement::VerticalPosition::Custom;
+		}
+
+		tempPosition.point = point;
+		q->setPosition(tempPosition);
+	}
+
+	QGraphicsItem::keyPressEvent(event);
+}
+
 /*!
  *	converts label's position to GraphicsItem's position.
  */
 QPointF TextLabelPrivate::positionFromItemPosition(QPointF itemPos) {
-	float x = itemPos.x();
-	float y = itemPos.y();
-	float w, h;
+	double x = itemPos.x();
+	double y = itemPos.y();
+	double w, h;
 	QPointF tmpPosition;
 	if (textWrapper.teXUsed) {
 		w = teXImage.width()*scaleFactor;
 		h = teXImage.height()*scaleFactor;
-	}
-	else {
+	} else {
 		w = staticText.size().width()*scaleFactor;
 		h = staticText.size().height()*scaleFactor;
 	}
 
 	//depending on the alignment, calculate the new position
 	switch (horizontalAlignment) {
-	case TextLabel::hAlignLeft:
+	case WorksheetElement::HorizontalAlignment::Left:
 		tmpPosition.setX(x + w/2);
 		break;
-	case TextLabel::hAlignCenter:
+	case WorksheetElement::HorizontalAlignment::Center:
 		tmpPosition.setX(x);
 		break;
-	case TextLabel::hAlignRight:
+	case WorksheetElement::HorizontalAlignment::Right:
 		tmpPosition.setX(x - w/2);
 		break;
 	}
 
 	switch (verticalAlignment) {
-	case TextLabel::vAlignTop:
+	case WorksheetElement::VerticalAlignment::Top:
 		tmpPosition.setY(y + h/2);
 		break;
-	case TextLabel::vAlignCenter:
+	case WorksheetElement::VerticalAlignment::Center:
 		tmpPosition.setY(y);
 		break;
-	case TextLabel::vAlignBottom:
+	case WorksheetElement::VerticalAlignment::Bottom:
 		tmpPosition.setY(y - h/2);
 		break;
 	}
@@ -893,10 +936,10 @@ void TextLabel::save(QXmlStreamWriter* writer) const {
 	writer->writeStartElement( "geometry" );
 	writer->writeAttribute( "x", QString::number(d->position.point.x()) );
 	writer->writeAttribute( "y", QString::number(d->position.point.y()) );
-	writer->writeAttribute( "horizontalPosition", QString::number(d->position.horizontalPosition) );
-	writer->writeAttribute( "verticalPosition", QString::number(d->position.verticalPosition) );
-	writer->writeAttribute( "horizontalAlignment", QString::number(d->horizontalAlignment) );
-	writer->writeAttribute( "verticalAlignment", QString::number(d->verticalAlignment) );
+	writer->writeAttribute( "horizontalPosition", QString::number(static_cast<int>(d->position.horizontalPosition)) );
+	writer->writeAttribute( "verticalPosition", QString::number(static_cast<int>(d->position.verticalPosition)) );
+	writer->writeAttribute( "horizontalAlignment", QString::number(static_cast<int>(d->horizontalAlignment)) );
+	writer->writeAttribute( "verticalAlignment", QString::number(static_cast<int>(d->verticalAlignment)) );
 	writer->writeAttribute( "rotationAngle", QString::number(d->rotationAngle) );
 	writer->writeAttribute( "visible", QString::number(d->isVisible()) );
 	writer->writeEndElement();
@@ -915,7 +958,7 @@ void TextLabel::save(QXmlStreamWriter* writer) const {
 
 	//border
 	writer->writeStartElement("border");
-	writer->writeAttribute("borderShape", QString::number(d->borderShape));
+	writer->writeAttribute("borderShape", QString::number(static_cast<int>(d->borderShape)));
 	WRITE_QPEN(d->borderPen);
 	writer->writeAttribute("borderOpacity", QString::number(d->borderOpacity));
 	writer->writeEndElement();
@@ -969,10 +1012,10 @@ bool TextLabel::load(XmlStreamReader* reader, bool preview) {
 			else
 				d->position.point.setY(str.toDouble());
 
-			READ_INT_VALUE("horizontalPosition", position.horizontalPosition, TextLabel::HorizontalPosition);
-			READ_INT_VALUE("verticalPosition", position.verticalPosition, TextLabel::VerticalPosition);
-			READ_INT_VALUE("horizontalAlignment", horizontalAlignment, TextLabel::HorizontalAlignment);
-			READ_INT_VALUE("verticalAlignment", verticalAlignment, TextLabel::VerticalAlignment);
+			READ_INT_VALUE("horizontalPosition", position.horizontalPosition, WorksheetElement::HorizontalPosition);
+			READ_INT_VALUE("verticalPosition", position.verticalPosition, WorksheetElement::VerticalPosition);
+			READ_INT_VALUE("horizontalAlignment", horizontalAlignment, WorksheetElement::HorizontalAlignment);
+			READ_INT_VALUE("verticalAlignment", verticalAlignment, WorksheetElement::VerticalAlignment);
 			READ_DOUBLE_VALUE("rotationAngle", rotationAngle);
 
 			str = attribs.value("visible").toString();
@@ -1042,8 +1085,27 @@ void TextLabel::loadThemeConfig(const KConfig& config) {
 	Q_D(TextLabel);
 
 	KConfigGroup group = config.group("Label");
-	d->fontColor = group.readEntry("FontColor", QColor(Qt::white));
-	d->backgroundColor = group.readEntry("BackgroundColor", QColor(Qt::black));
+	d->fontColor = group.readEntry("FontColor", QColor(Qt::black)); // used when it's latex text
+	d->backgroundColor = group.readEntry("BackgroundColor", QColor(Qt::white)); // used when it's latex text
+
+	if (!d->textWrapper.teXUsed && !d->textWrapper.text.isEmpty()) {
+		// TODO: Replace QTextEdit by QTextDocument, because this does not contain the graphical stuff
+		// to set the color in a html text, a qTextEdit must be used
+		QTextEdit te;
+		te.setHtml(d->textWrapper.text);
+		te.selectAll();
+		te.setTextColor(d->fontColor);
+		//te.setTextBackgroundColor(backgroundColor); // for plain text no background color supported, due to bug https://bugreports.qt.io/browse/QTBUG-25420
+
+		// update the text. also in the Widget to which is connected
+		TextWrapper wrapper(te.toHtml(), false, true);
+		setText(wrapper);
+	}
+
+	// otherwise when changing theme while the textlabel dock is visible, the
+	// color comboboxes do not change the color
+	backgroundColorChanged(d->backgroundColor);
+	fontColorChanged(d->fontColor);
 
 	group = config.group("CartesianPlot");
 	QPen pen = this->borderPen();
@@ -1052,8 +1114,6 @@ void TextLabel::loadThemeConfig(const KConfig& config) {
 	pen.setWidthF(group.readEntry("BorderWidth", pen.widthF()));
 	this->setBorderPen(pen);
 	this->setBorderOpacity(group.readEntry("BorderOpacity", this->borderOpacity()));
-
-	d->updateText();
 }
 
 void TextLabel::saveThemeConfig(const KConfig& config) {
