@@ -4,8 +4,8 @@
     Project              : LabPlot
     Description          : Cartesian plot
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2018 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2018 by Stefan Gerlach (stefan.gerlach@uni.kn)
+    Copyright            : (C) 2011-2020 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2012-2019 Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
 
@@ -62,18 +62,18 @@ public:
 	explicit CartesianPlot(const QString &name);
 	~CartesianPlot() override;
 
-	enum Scale {ScaleLinear, ScaleLog10, ScaleLog2, ScaleLn, ScaleLog10Abs, ScaleLog2Abs, ScaleLnAbs, ScaleSqrt, ScaleX2};
-	enum Type {FourAxes, TwoAxes, TwoAxesCentered, TwoAxesCenteredZero};
-	enum RangeFormat {Numeric, DateTime};
-	enum RangeType {RangeFree, RangeLast, RangeFirst};
-	enum RangeBreakStyle {RangeBreakSimple, RangeBreakVertical, RangeBreakSloped};
-	enum MouseMode {SelectionMode, ZoomSelectionMode, ZoomXSelectionMode, ZoomYSelectionMode, Cursor};
-	enum NavigationOperation {ScaleAuto, ScaleAutoX, ScaleAutoY, ZoomIn, ZoomOut, ZoomInX, ZoomOutX,
+	enum class Scale {Linear, Log10, Log2, Ln, Log10Abs, Log2Abs, LnAbs, Sqrt, X2};
+	enum class Type {FourAxes, TwoAxes, TwoAxesCentered, TwoAxesCenteredZero};
+	enum class RangeFormat {Numeric, DateTime};
+	enum class RangeType {Free, Last, First};
+	enum class RangeBreakStyle {Simple, Vertical, Sloped};
+	enum class MouseMode {Selection, ZoomSelection, ZoomXSelection, ZoomYSelection, Cursor};
+	enum class NavigationOperation {ScaleAuto, ScaleAutoX, ScaleAutoY, ZoomIn, ZoomOut, ZoomInX, ZoomOutX,
 	                          ZoomInY, ZoomOutY, ShiftLeftX, ShiftRightX, ShiftUpY, ShiftDownY
 	                         };
 
 	struct RangeBreak {
-		RangeBreak() : start(NAN), end(NAN), position(0.5), style(RangeBreakSloped) {}
+		RangeBreak() : start(NAN), end(NAN), position(0.5), style(RangeBreakStyle::Sloped) {}
 		bool isValid() const {
 			return (!std::isnan(start) && !std::isnan(end));
 		}
@@ -93,15 +93,18 @@ public:
 		int lastChanged;
 	};
 
-	void initDefault(Type = FourAxes);
+	void setType(Type type);
+	Type type() const;
+
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
 	QMenu* analysisMenu();
 	QVector<AbstractAspect*> dependsOn() const override;
 	void setRect(const QRectF&) override;
 	QRectF dataRect() const;
-	void setMouseMode(const MouseMode);
-	void setLocked(const bool);
+	void setMouseMode(MouseMode);
+	void setLocked(bool);
+	bool isLocked() const;
 	MouseMode mouseMode() const;
 	void navigate(NavigationOperation);
 	void setSuppressDataChangedSignal(bool);
@@ -164,6 +167,8 @@ private:
 	void initMenus();
 	void setColorPalette(const KConfig&);
 	const XYCurve* currentCurve() const;
+	void shift(bool x, bool leftOrDown);
+	void zoom(bool x, bool in);
 
 	void calculateCurvesXMinMax(bool completeRange = true);
 	void calculateCurvesYMinMax(bool completeRange = true);
@@ -194,7 +199,9 @@ private:
 	QAction* addVerticalAxisAction;
 	QAction* addLegendAction;
 	QAction* addTextLabelAction;
+	QAction* addImageAction;
 	QAction* addCustomPointAction;
+	QAction* addReferenceLineAction;
 
 	//scaling, zooming, navigation actions
 	QAction* scaleAutoXAction;
@@ -251,24 +258,30 @@ public slots:
 
 	void addLegend();
 	void addTextLabel();
+	void addImage();
 	void addCustomPoint();
+	void addReferenceLine();
+
 	void scaleAutoTriggered();
 	bool scaleAuto();
 	bool scaleAutoX();
 	bool scaleAutoY();
+
 	void zoomIn();
 	void zoomOut();
 	void zoomInX();
 	void zoomOutX();
 	void zoomInY();
 	void zoomOutY();
+
 	void shiftLeftX();
 	void shiftRightX();
 	void shiftUpY();
 	void shiftDownY();
-	void cursor();
-	void dataChanged();
 
+	void cursor();
+
+	void dataChanged();
 	void curveLinePenChanged(QPen);
 
 private slots:
@@ -298,11 +311,11 @@ signals:
 	void xAutoScaleChanged(bool);
 	void xMinChanged(double);
 	void xMaxChanged(double);
-	void xScaleChanged(int);
+	void xScaleChanged(CartesianPlot::Scale);
 	void yAutoScaleChanged(bool);
 	void yMinChanged(double);
 	void yMaxChanged(double);
-	void yScaleChanged(int);
+	void yScaleChanged(CartesianPlot::Scale);
 	void xRangeBreakingEnabledChanged(bool);
 	void xRangeBreaksChanged(const CartesianPlot::RangeBreaks&);
 	void yRangeBreakingEnabledChanged(bool);
@@ -324,7 +337,7 @@ signals:
 	void cursorPenChanged(QPen);
 	void curveDataChanged(const XYCurve*);
 	void curveVisibilityChangedSignal();
-	void mouseModeChanged(MouseMode);
+	void mouseModeChanged(CartesianPlot::MouseMode);
 	void cursor0EnableChanged(bool enable);
 	void cursor1EnableChanged(bool enable);
 };
