@@ -39,7 +39,7 @@ class QFrame;
 class QLabel;
 class QLineEdit;
 class QModelIndex;
-class QPushButton;
+class QToolButton;
 class QSignalMapper;
 class QTreeView;
 class QXmlStreamWriter;
@@ -51,17 +51,20 @@ class ProjectExplorer : public QWidget {
 
 public:
 	explicit ProjectExplorer(QWidget* parent = nullptr);
+	~ProjectExplorer() override;
 
 	void setCurrentAspect(const AbstractAspect*);
 	void setModel(AspectTreeModel*);
 	void setProject(Project*);
 	QModelIndex currentIndex() const;
 	void updateSelectedAspects();
+	void search();
 
 private:
 	void createActions();
 	void contextMenuEvent(QContextMenuEvent*) override;
 	bool eventFilter(QObject*, QEvent*) override;
+	void keyPressEvent(QKeyEvent*) override;
 	void collapseParents(const QModelIndex&, const QList<QModelIndex>& expanded);
 	bool filter(const QModelIndex&, const QString&);
 	int m_columnToHide{0};
@@ -69,6 +72,7 @@ private:
 	Project* m_project{nullptr};
 	QPoint m_dragStartPos;
 	bool m_dragStarted{false};
+	bool m_changeSelectionFromView{false};
 
 	QAction* caseSensitiveAction;
 	QAction* matchCompleteWordAction;
@@ -84,8 +88,7 @@ private:
 
 	QFrame* m_frameFilter;
 	QLineEdit* m_leFilter;
-	QPushButton* bClearFilter;
-	QPushButton* bFilterOptions;
+	QToolButton* bFilterOptions;
 
 private slots:
 	void projectLoaded();
