@@ -80,6 +80,8 @@ WorksheetDock::WorksheetDock(QWidget *parent): BaseDock(parent) {
 		layout->setVerticalSpacing(2);
 	}
 
+	updateLocale();
+
 	//SLOTs
 	//General
 	connect(ui.leName, &QLineEdit::textChanged, this, &WorksheetDock::nameChanged);
@@ -141,7 +143,7 @@ WorksheetDock::WorksheetDock(QWidget *parent): BaseDock(parent) {
 	connect(m_themeHandler, &ThemeHandler::loadThemeRequested, this, &WorksheetDock::loadTheme);
 	connect(m_themeHandler, &ThemeHandler::info, this, &WorksheetDock::info);
 
-	auto* templateHandler = new TemplateHandler(this, TemplateHandler::Worksheet);
+	auto* templateHandler = new TemplateHandler(this, TemplateHandler::ClassName::Worksheet);
 	layout->addWidget(templateHandler);
 	connect(templateHandler, &TemplateHandler::loadConfigRequested, this, &WorksheetDock::loadConfigFromTemplate);
 	connect(templateHandler, &TemplateHandler::saveConfigRequested, this, &WorksheetDock::saveConfigAsTemplate);
@@ -213,6 +215,63 @@ void WorksheetDock::setWorksheets(QList<Worksheet*> list) {
 	m_initializing = false;
 }
 
+void WorksheetDock::updateLocale() {
+	SET_NUMBER_LOCALE
+	ui.sbWidth->setLocale(numberLocale);
+	ui.sbHeight->setLocale(numberLocale);
+	ui.sbLayoutTopMargin->setLocale(numberLocale);
+	ui.sbLayoutBottomMargin->setLocale(numberLocale);
+	ui.sbLayoutLeftMargin->setLocale(numberLocale);
+	ui.sbLayoutRightMargin->setLocale(numberLocale);
+	ui.sbLayoutHorizontalSpacing->setLocale(numberLocale);
+	ui.sbLayoutVerticalSpacing->setLocale(numberLocale);
+}
+
+void WorksheetDock::updateUnits() {
+	const KConfigGroup group = KSharedConfig::openConfig()->group(QLatin1String("Settings_General"));
+	BaseDock::Units units = (BaseDock::Units)group.readEntry("Units", static_cast<int>(Units::Metric));
+	if (units == m_units)
+		return;
+
+	m_units = units;
+	Lock lock(m_initializing);
+	QString suffix;
+	if (m_units == Units::Metric) {
+		//convert from imperial to metric
+		m_worksheetUnit = Worksheet::Unit::Centimeter;
+		suffix = QLatin1String(" cm");
+		ui.sbWidth->setValue(ui.sbWidth->value()*2.54);
+		ui.sbHeight->setValue(ui.sbHeight->value()*2.54);
+		ui.sbLayoutTopMargin->setValue(ui.sbLayoutTopMargin->value()*2.54);
+		ui.sbLayoutBottomMargin->setValue(ui.sbLayoutBottomMargin->value()*2.54);
+		ui.sbLayoutLeftMargin->setValue(ui.sbLayoutLeftMargin->value()*2.54);
+		ui.sbLayoutRightMargin->setValue(ui.sbLayoutRightMargin->value()*2.54);
+		ui.sbLayoutHorizontalSpacing->setValue(ui.sbLayoutHorizontalSpacing->value()*2.54);
+		ui.sbLayoutVerticalSpacing->setValue(ui.sbLayoutVerticalSpacing->value()*2.54);
+	} else {
+		//convert from metric to imperial
+		m_worksheetUnit = Worksheet::Unit::Inch;
+		suffix = QLatin1String(" in");
+		ui.sbWidth->setValue(ui.sbWidth->value()/2.54);
+		ui.sbHeight->setValue(ui.sbHeight->value()/2.54);
+		ui.sbLayoutTopMargin->setValue(ui.sbLayoutTopMargin->value()/2.54);
+		ui.sbLayoutBottomMargin->setValue(ui.sbLayoutBottomMargin->value()/2.54);
+		ui.sbLayoutLeftMargin->setValue(ui.sbLayoutLeftMargin->value()/2.54);
+		ui.sbLayoutRightMargin->setValue(ui.sbLayoutRightMargin->value()/2.54);
+		ui.sbLayoutHorizontalSpacing->setValue(ui.sbLayoutHorizontalSpacing->value()/2.54);
+		ui.sbLayoutVerticalSpacing->setValue(ui.sbLayoutVerticalSpacing->value()/2.54);
+	}
+
+	ui.sbWidth->setSuffix(suffix);
+	ui.sbHeight->setSuffix(suffix);
+	ui.sbLayoutTopMargin->setSuffix(suffix);
+	ui.sbLayoutBottomMargin->setSuffix(suffix);
+	ui.sbLayoutLeftMargin->setSuffix(suffix);
+	ui.sbLayoutRightMargin->setSuffix(suffix);
+	ui.sbLayoutHorizontalSpacing->setSuffix(suffix);
+	ui.sbLayoutVerticalSpacing->setSuffix(suffix);
+}
+
 /*!
 	Checks whether the size is one of the QPageSize::PageSizeId and
 	updates Size and Orientation checkbox when width/height changes.
@@ -223,9 +282,14 @@ void WorksheetDock::updatePaperSize() {
 		return;
 	}
 
-	//In UI we use cm, so we need to convert to mm first before we check with QPageSize
-	float w = (float)ui.sbWidth->value()*10;
-	float h = (float)ui.sbHeight->value()*10;
+	double w = ui.sbWidth->value();
+	double h = ui.sbHeight->value();
+	if (m_units == Units::Metric) {
+		//In UI we use cm, so we need to convert to mm first before we check with QPageSize
+		w *= 10;
+		h *= 10;
+	}
+
 	const QSizeF s = QSizeF(w, h);
 	const QSizeF st = s.transposed();
 
@@ -237,7 +301,8 @@ void WorksheetDock::updatePaperSize() {
 			continue;
 
 		const auto id = v.value<QPageSize::PageSizeId>();
-		const QSizeF ps = QPageSize::size(id, QPageSize::Millimeter);
+		QPageSize::Unit pageUnit = (m_units == Units::Metric) ? QPageSize::Millimeter : QPageSize::Inch;
+		const QSizeF ps = QPageSize::size(id, pageUnit);
 		if (s == ps) { //check the portrait-orientation first
 			ui.cbSize->setCurrentIndex(i);
 			ui.cbOrientation->setCurrentIndex(0);  //a QPageSize::PaperSize in portrait-orientation was found
@@ -259,14 +324,29 @@ void WorksheetDock::updatePaperSize() {
 //****** SLOTs for changes triggered in WorksheetDock *********
 //*************************************************************
 void WorksheetDock::retranslateUi() {
-	m_initializing = true;
+	Lock lock(m_initializing);
 
 	//Geometry
 	ui.cbOrientation->clear();
 	ui.cbOrientation->addItem(i18n("Portrait"));
 	ui.cbOrientation->addItem(i18n("Landscape"));
 
-	const QVector<QPageSize::PageSizeId> pageSizes = {
+	QString suffix;
+	if (m_units == Units::Metric)
+		suffix = QLatin1String(" cm");
+	else
+		suffix = QLatin1String(" in");
+
+	ui.sbWidth->setSuffix(suffix);
+	ui.sbHeight->setSuffix(suffix);
+	ui.sbLayoutTopMargin->setSuffix(suffix);
+	ui.sbLayoutBottomMargin->setSuffix(suffix);
+	ui.sbLayoutLeftMargin->setSuffix(suffix);
+	ui.sbLayoutRightMargin->setSuffix(suffix);
+	ui.sbLayoutHorizontalSpacing->setSuffix(suffix);
+	ui.sbLayoutVerticalSpacing->setSuffix(suffix);
+
+	const QVector<QPageSize::PageSizeId> pageSizeIds = {
 		QPageSize::A0,
 		QPageSize::A1,
 		QPageSize::A2,
@@ -301,9 +381,8 @@ void WorksheetDock::retranslateUi() {
 	};
 	ui.cbSize->clear();
 	ui.cbSize->addItem(i18n("View Size"));
-	for (QPageSize::PageSizeId id : pageSizes) {
+	for (auto id : pageSizeIds)
 		ui.cbSize->addItem(QPageSize::name(id), id);
-	}
 	ui.cbSize->insertSeparator(1);
 
 	//Background
@@ -328,8 +407,6 @@ void WorksheetDock::retranslateUi() {
 	ui.cbBackgroundImageStyle->addItem(i18n("Tiled"));
 	ui.cbBackgroundImageStyle->addItem(i18n("Center Tiled"));
 	GuiTools::updateBrushStyles(ui.cbBackgroundBrushStyle, Qt::SolidPattern);
-
-	m_initializing = false;
 }
 
 // "General"-tab
@@ -364,6 +441,7 @@ void WorksheetDock::sizeChanged(int i) {
 	if (m_initializing)
 		return;
 
+	Lock lock(m_initializing);
 	if (i == 0) {
 		//use the complete view size (first item in the combox is selected)
 		for (auto* worksheet : m_worksheetList)
@@ -376,18 +454,20 @@ void WorksheetDock::sizeChanged(int i) {
 	} else {
 		//determine the width and the height of the to be used predefined layout
 		QSizeF s = QPageSize::size(index, QPageSize::Millimeter);
-		if (ui.cbOrientation->currentIndex() == 1) {
+		if (ui.cbOrientation->currentIndex() == 1)
 			s.transpose();
+
+		//s is in mm, in UI we show everything in cm/in
+		if (m_units == Units::Metric) {
+			ui.sbWidth->setValue(s.width()/10);
+			ui.sbHeight->setValue(s.height()/10);
+		} else {
+			ui.sbWidth->setValue(s.width()/25.4);
+			ui.sbHeight->setValue(s.height()/25.4);
 		}
 
-		m_initializing = true;
-		//s is in mm, in UI we show everything in cm
-		ui.sbWidth->setValue(s.width()/10);
-		ui.sbHeight->setValue(s.height()/10);
-		m_initializing = false;
-
-		float w = Worksheet::convertToSceneUnits(s.width(), Worksheet::Millimeter);
-		float h = Worksheet::convertToSceneUnits(s.height(), Worksheet::Millimeter);
+		float w = Worksheet::convertToSceneUnits(s.width(), Worksheet::Unit::Millimeter);
+		float h = Worksheet::convertToSceneUnits(s.height(), Worksheet::Unit::Millimeter);
 		for (auto* worksheet : m_worksheetList) {
 			worksheet->setUseViewSize(false);
 			worksheet->setPageRect(QRect(0,0,w,h));
@@ -399,8 +479,8 @@ void WorksheetDock::sizeChanged() {
 	if (m_initializing)
 		return;
 
-	int w = Worksheet::convertToSceneUnits(ui.sbWidth->value(), Worksheet::Centimeter);
-	int h = Worksheet::convertToSceneUnits(ui.sbHeight->value(), Worksheet::Centimeter);
+	int w = Worksheet::convertToSceneUnits(ui.sbWidth->value(), m_worksheetUnit);
+	int h = Worksheet::convertToSceneUnits(ui.sbHeight->value(), m_worksheetUnit);
 	for (auto* worksheet : m_worksheetList)
 		worksheet->setPageRect(QRect(0,0,w,h));
 }
@@ -417,7 +497,7 @@ void WorksheetDock::orientationChanged(int index) {
 void WorksheetDock::backgroundTypeChanged(int index) {
 	auto type = (PlotArea::BackgroundType)index;
 
-	if (type == PlotArea::Color) {
+	if (type == PlotArea::BackgroundType::Color) {
 		ui.lBackgroundColorStyle->show();
 		ui.cbBackgroundColorStyle->show();
 		ui.lBackgroundImageStyle->hide();
@@ -433,7 +513,7 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 		ui.kcbBackgroundFirstColor->show();
 
 		auto style = (PlotArea::BackgroundColorStyle)ui.cbBackgroundColorStyle->currentIndex();
-		if (style == PlotArea::SingleColor) {
+		if (style == PlotArea::BackgroundColorStyle::SingleColor) {
 			ui.lBackgroundFirstColor->setText(i18n("Color:"));
 			ui.lBackgroundSecondColor->hide();
 			ui.kcbBackgroundSecondColor->hide();
@@ -442,7 +522,7 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 			ui.lBackgroundSecondColor->show();
 			ui.kcbBackgroundSecondColor->show();
 		}
-	} else if (type == PlotArea::Image) {
+	} else if (type == PlotArea::BackgroundType::Image) {
 		ui.lBackgroundFirstColor->hide();
 		ui.kcbBackgroundFirstColor->hide();
 		ui.lBackgroundSecondColor->hide();
@@ -457,7 +537,7 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 		ui.lBackgroundFileName->show();
 		ui.leBackgroundFileName->show();
 		ui.bOpen->show();
-	} else if (type == PlotArea::Pattern) {
+	} else if (type == PlotArea::BackgroundType::Pattern) {
 		ui.lBackgroundFirstColor->setText(i18n("Color:"));
 		ui.lBackgroundFirstColor->show();
 		ui.kcbBackgroundFirstColor->show();
@@ -485,7 +565,7 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 void WorksheetDock::backgroundColorStyleChanged(int index) {
 	auto style = (PlotArea::BackgroundColorStyle)index;
 
-	if (style == PlotArea::SingleColor) {
+	if (style == PlotArea::BackgroundColorStyle::SingleColor) {
 		ui.lBackgroundFirstColor->setText(i18n("Color:"));
 		ui.lBackgroundSecondColor->hide();
 		ui.kcbBackgroundSecondColor->hide();
@@ -555,7 +635,7 @@ void WorksheetDock::backgroundOpacityChanged(int value) {
 void WorksheetDock::layoutChanged(int index) {
 	auto layout = (Worksheet::Layout)index;
 
-	bool b = (layout != Worksheet::NoLayout);
+	bool b = (layout != Worksheet::Layout::NoLayout);
 	ui.sbLayoutTopMargin->setEnabled(b);
 	ui.sbLayoutBottomMargin->setEnabled(b);
 	ui.sbLayoutLeftMargin->setEnabled(b);
@@ -571,7 +651,7 @@ void WorksheetDock::layoutChanged(int index) {
 
 	if (b) {
 		//show grid specific settings if grid layout selected
-		bool grid = (layout == Worksheet::GridLayout);
+		bool grid = (layout == Worksheet::Layout::GridLayout);
 		ui.lGrid->setVisible(grid);
 		ui.lRowCount->setVisible(grid);
 		ui.sbLayoutRowCount->setVisible(grid);
@@ -598,7 +678,7 @@ void WorksheetDock::layoutTopMarginChanged(double margin) {
 		return;
 
 	for (auto* worksheet : m_worksheetList)
-		worksheet->setLayoutTopMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
+		worksheet->setLayoutTopMargin(Worksheet::convertToSceneUnits(margin, m_worksheetUnit));
 }
 
 void WorksheetDock::layoutBottomMarginChanged(double margin) {
@@ -606,7 +686,7 @@ void WorksheetDock::layoutBottomMarginChanged(double margin) {
 		return;
 
 	for (auto* worksheet : m_worksheetList)
-		worksheet->setLayoutBottomMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
+		worksheet->setLayoutBottomMargin(Worksheet::convertToSceneUnits(margin, m_worksheetUnit));
 }
 
 void WorksheetDock::layoutLeftMarginChanged(double margin) {
@@ -614,7 +694,7 @@ void WorksheetDock::layoutLeftMarginChanged(double margin) {
 		return;
 
 	for (auto* worksheet : m_worksheetList)
-		worksheet->setLayoutLeftMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
+		worksheet->setLayoutLeftMargin(Worksheet::convertToSceneUnits(margin, m_worksheetUnit));
 }
 
 void WorksheetDock::layoutRightMarginChanged(double margin) {
@@ -622,7 +702,7 @@ void WorksheetDock::layoutRightMarginChanged(double margin) {
 		return;
 
 	for (auto* worksheet : m_worksheetList)
-		worksheet->setLayoutRightMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
+		worksheet->setLayoutRightMargin(Worksheet::convertToSceneUnits(margin, m_worksheetUnit));
 }
 
 void WorksheetDock::layoutHorizontalSpacingChanged(double spacing) {
@@ -630,7 +710,7 @@ void WorksheetDock::layoutHorizontalSpacingChanged(double spacing) {
 		return;
 
 	for (auto* worksheet : m_worksheetList)
-		worksheet->setLayoutHorizontalSpacing(Worksheet::convertToSceneUnits(spacing, Worksheet::Centimeter));
+		worksheet->setLayoutHorizontalSpacing(Worksheet::convertToSceneUnits(spacing, m_worksheetUnit));
 }
 
 void WorksheetDock::layoutVerticalSpacingChanged(double spacing) {
@@ -638,7 +718,7 @@ void WorksheetDock::layoutVerticalSpacingChanged(double spacing) {
 		return;
 
 	for (auto* worksheet : m_worksheetList)
-		worksheet->setLayoutVerticalSpacing(Worksheet::convertToSceneUnits(spacing, Worksheet::Centimeter));
+		worksheet->setLayoutVerticalSpacing(Worksheet::convertToSceneUnits(spacing, m_worksheetUnit));
 }
 
 void WorksheetDock::layoutRowCountChanged(int count) {
@@ -676,7 +756,7 @@ void WorksheetDock::selectFile() {
 	if (path.isEmpty())
 		return; //cancel was clicked in the file-dialog
 
-	int pos = path.lastIndexOf(QDir::separator());
+	int pos = path.lastIndexOf(QLatin1String("/"));
 	if (pos != -1) {
 		QString newDir = path.left(pos);
 		if (newDir != dir)
@@ -693,11 +773,9 @@ void WorksheetDock::fileNameChanged() {
 	if (m_initializing)
 		return;
 
-	QString fileName = ui.leBackgroundFileName->text();
-	if (!fileName.isEmpty() && !QFile::exists(fileName))
-		ui.leBackgroundFileName->setStyleSheet("QLineEdit{background:red;}");
-	else
-		ui.leBackgroundFileName->setStyleSheet(QString());
+	const QString& fileName = ui.leBackgroundFileName->text();
+	bool invalid = (!fileName.isEmpty() && !QFile::exists(fileName));
+	GuiTools::highlight(ui.leBackgroundFileName, invalid);
 
 	for (auto* worksheet : m_worksheetList)
 		worksheet->setBackgroundFileName(fileName);
@@ -726,27 +804,27 @@ void WorksheetDock::worksheetScaleContentChanged(bool scaled) {
 
 void WorksheetDock::worksheetPageRectChanged(const QRectF& rect) {
 	m_initializing = true;
-	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits(rect.width(), Worksheet::Centimeter));
-	ui.sbHeight->setValue(Worksheet::convertFromSceneUnits(rect.height(), Worksheet::Centimeter));
+	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits(rect.width(), m_worksheetUnit));
+	ui.sbHeight->setValue(Worksheet::convertFromSceneUnits(rect.height(), m_worksheetUnit));
 	updatePaperSize();
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetBackgroundTypeChanged(PlotArea::BackgroundType type) {
 	m_initializing = true;
-	ui.cbBackgroundType->setCurrentIndex(type);
+	ui.cbBackgroundType->setCurrentIndex(static_cast<int>(type));
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetBackgroundColorStyleChanged(PlotArea::BackgroundColorStyle style) {
 	m_initializing = true;
-	ui.cbBackgroundColorStyle->setCurrentIndex(style);
+	ui.cbBackgroundColorStyle->setCurrentIndex(static_cast<int>(style));
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetBackgroundImageStyleChanged(PlotArea::BackgroundImageStyle style) {
 	m_initializing = true;
-	ui.cbBackgroundImageStyle->setCurrentIndex(style);
+	ui.cbBackgroundImageStyle->setCurrentIndex(static_cast<int>(style));
 	m_initializing = false;
 }
 
@@ -782,43 +860,43 @@ void WorksheetDock::worksheetBackgroundOpacityChanged(float opacity) {
 
 void WorksheetDock::worksheetLayoutChanged(Worksheet::Layout layout) {
 	m_initializing = true;
-	ui.cbLayout->setCurrentIndex(layout);
+	ui.cbLayout->setCurrentIndex(static_cast<int>(layout));
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetLayoutTopMarginChanged(float value) {
 	m_initializing = true;
-	ui.sbLayoutTopMargin->setValue(Worksheet::convertFromSceneUnits(value, Worksheet::Centimeter));
+	ui.sbLayoutTopMargin->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetLayoutBottomMarginChanged(float value) {
 	m_initializing = true;
-	ui.sbLayoutBottomMargin->setValue(Worksheet::convertFromSceneUnits(value, Worksheet::Centimeter));
+	ui.sbLayoutBottomMargin->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetLayoutLeftMarginChanged(float value) {
 	m_initializing = true;
-	ui.sbLayoutLeftMargin->setValue(Worksheet::convertFromSceneUnits(value, Worksheet::Centimeter));
+	ui.sbLayoutLeftMargin->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetLayoutRightMarginChanged(float value) {
 	m_initializing = true;
-	ui.sbLayoutRightMargin->setValue(Worksheet::convertFromSceneUnits(value, Worksheet::Centimeter));
+	ui.sbLayoutRightMargin->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetLayoutVerticalSpacingChanged(float value) {
 	m_initializing = true;
-	ui.sbLayoutVerticalSpacing->setValue(Worksheet::convertFromSceneUnits(value, Worksheet::Centimeter));
+	ui.sbLayoutVerticalSpacing->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
 	m_initializing = false;
 }
 
 void WorksheetDock::worksheetLayoutHorizontalSpacingChanged(float value) {
 	m_initializing = true;
-	ui.sbLayoutHorizontalSpacing->setValue(Worksheet::convertFromSceneUnits(value, Worksheet::Centimeter));
+	ui.sbLayoutHorizontalSpacing->setValue(Worksheet::convertFromSceneUnits(value, m_worksheetUnit));
 	m_initializing = false;
 }
 
@@ -840,8 +918,8 @@ void WorksheetDock::worksheetLayoutColumnCountChanged(int value) {
 void WorksheetDock::load() {
 	// Geometry
 	ui.chScaleContent->setChecked(m_worksheet->scaleContent());
-	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits( m_worksheet->pageRect().width(), Worksheet::Centimeter) );
-	ui.sbHeight->setValue(Worksheet::convertFromSceneUnits( m_worksheet->pageRect().height(), Worksheet::Centimeter) );
+	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits( m_worksheet->pageRect().width(), m_worksheetUnit) );
+	ui.sbHeight->setValue(Worksheet::convertFromSceneUnits( m_worksheet->pageRect().height(), m_worksheetUnit) );
 	updatePaperSize();
 
 	// Background-tab
@@ -855,19 +933,18 @@ void WorksheetDock::load() {
 	ui.sbBackgroundOpacity->setValue( qRound(m_worksheet->backgroundOpacity()*100) );
 
 	//highlight the text field for the background image red if an image is used and cannot be found
-	if (!m_worksheet->backgroundFileName().isEmpty() && !QFile::exists(m_worksheet->backgroundFileName()))
-		ui.leBackgroundFileName->setStyleSheet("QLineEdit{background:red;}");
-	else
-		ui.leBackgroundFileName->setStyleSheet(QString());
+	const QString& fileName = m_worksheet->backgroundFileName();
+	bool invalid = (!fileName.isEmpty() && !QFile::exists(fileName));
+	GuiTools::highlight(ui.leBackgroundFileName, invalid);
 
 	// Layout
 	ui.cbLayout->setCurrentIndex( (int) m_worksheet->layout() );
-	ui.sbLayoutTopMargin->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutTopMargin(), Worksheet::Centimeter) );
-	ui.sbLayoutBottomMargin->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutBottomMargin(), Worksheet::Centimeter) );
-	ui.sbLayoutLeftMargin->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutLeftMargin(), Worksheet::Centimeter) );
-	ui.sbLayoutRightMargin->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutRightMargin(), Worksheet::Centimeter) );
-	ui.sbLayoutHorizontalSpacing->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutHorizontalSpacing(), Worksheet::Centimeter) );
-	ui.sbLayoutVerticalSpacing->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutVerticalSpacing(), Worksheet::Centimeter) );
+	ui.sbLayoutTopMargin->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutTopMargin(), m_worksheetUnit) );
+	ui.sbLayoutBottomMargin->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutBottomMargin(), m_worksheetUnit) );
+	ui.sbLayoutLeftMargin->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutLeftMargin(), m_worksheetUnit) );
+	ui.sbLayoutRightMargin->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutRightMargin(), m_worksheetUnit) );
+	ui.sbLayoutHorizontalSpacing->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutHorizontalSpacing(), m_worksheetUnit) );
+	ui.sbLayoutVerticalSpacing->setValue( Worksheet::convertFromSceneUnits(m_worksheet->layoutVerticalSpacing(), m_worksheetUnit) );
 
 	ui.sbLayoutRowCount->setValue( m_worksheet->layoutRowCount() );
 	ui.sbLayoutColumnCount->setValue( m_worksheet->layoutColumnCount() );
@@ -876,7 +953,7 @@ void WorksheetDock::load() {
 void WorksheetDock::loadConfigFromTemplate(KConfig& config) {
 	//extract the name of the template from the file name
 	QString name;
-	int index = config.name().lastIndexOf(QDir::separator());
+	int index = config.name().lastIndexOf(QLatin1String("/"));
 	if (index != -1)
 		name = config.name().right(config.name().size() - index - 1);
 	else
@@ -897,8 +974,8 @@ void WorksheetDock::loadConfig(KConfig& config) {
 
 	// Geometry
 	ui.chScaleContent->setChecked(group.readEntry("ScaleContent", false));
-	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits(group.readEntry("Width", m_worksheet->pageRect().width()), Worksheet::Centimeter));
-	ui.sbHeight->setValue(Worksheet::convertFromSceneUnits(group.readEntry("Height", m_worksheet->pageRect().height()), Worksheet::Centimeter));
+	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits(group.readEntry("Width", m_worksheet->pageRect().width()), m_worksheetUnit));
+	ui.sbHeight->setValue(Worksheet::convertFromSceneUnits(group.readEntry("Height", m_worksheet->pageRect().height()), m_worksheetUnit));
 	if (group.readEntry("UseViewSize", false))
 		ui.cbSize->setCurrentIndex(0);
 	else
@@ -915,12 +992,13 @@ void WorksheetDock::loadConfig(KConfig& config) {
 	ui.sbBackgroundOpacity->setValue( qRound(group.readEntry("BackgroundOpacity", m_worksheet->backgroundOpacity())*100) );
 
 	// Layout
-	ui.sbLayoutTopMargin->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutTopMargin", m_worksheet->layoutTopMargin()), Worksheet::Centimeter) );
-	ui.sbLayoutBottomMargin->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutBottomMargin", m_worksheet->layoutBottomMargin()), Worksheet::Centimeter) );
-	ui.sbLayoutLeftMargin->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutLeftMargin", m_worksheet->layoutLeftMargin()), Worksheet::Centimeter) );
-	ui.sbLayoutRightMargin->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutRightMargin", m_worksheet->layoutRightMargin()), Worksheet::Centimeter) );
-	ui.sbLayoutHorizontalSpacing->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutHorizontalSpacing", m_worksheet->layoutHorizontalSpacing()), Worksheet::Centimeter) );
-	ui.sbLayoutVerticalSpacing->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutVerticalSpacing", m_worksheet->layoutVerticalSpacing()), Worksheet::Centimeter) );
+	ui.cbLayout->setCurrentIndex( group.readEntry("Layout", (int)m_worksheet->layout()) );
+	ui.sbLayoutTopMargin->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutTopMargin", m_worksheet->layoutTopMargin()), m_worksheetUnit) );
+	ui.sbLayoutBottomMargin->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutBottomMargin", m_worksheet->layoutBottomMargin()), m_worksheetUnit) );
+	ui.sbLayoutLeftMargin->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutLeftMargin", m_worksheet->layoutLeftMargin()), m_worksheetUnit) );
+	ui.sbLayoutRightMargin->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutRightMargin", m_worksheet->layoutRightMargin()), m_worksheetUnit) );
+	ui.sbLayoutHorizontalSpacing->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutHorizontalSpacing", m_worksheet->layoutHorizontalSpacing()), m_worksheetUnit) );
+	ui.sbLayoutVerticalSpacing->setValue( Worksheet::convertFromSceneUnits(group.readEntry("LayoutVerticalSpacing", m_worksheet->layoutVerticalSpacing()), m_worksheetUnit) );
 
 	ui.sbLayoutRowCount->setValue(group.readEntry("LayoutRowCount", m_worksheet->layoutRowCount()));
 	ui.sbLayoutColumnCount->setValue(group.readEntry("LayoutColumnCount", m_worksheet->layoutColumnCount()));
@@ -932,8 +1010,8 @@ void WorksheetDock::saveConfigAsTemplate(KConfig& config) {
 	//General
 	group.writeEntry("ScaleContent",ui.chScaleContent->isChecked());
 	group.writeEntry("UseViewSize",ui.cbSize->currentIndex() == 0);
-	group.writeEntry("Width",Worksheet::convertToSceneUnits(ui.sbWidth->value(), Worksheet::Centimeter));
-	group.writeEntry("Height",Worksheet::convertToSceneUnits(ui.sbHeight->value(), Worksheet::Centimeter));
+	group.writeEntry("Width",Worksheet::convertToSceneUnits(ui.sbWidth->value(), m_worksheetUnit));
+	group.writeEntry("Height",Worksheet::convertToSceneUnits(ui.sbHeight->value(), m_worksheetUnit));
 
 	//Background
 	group.writeEntry("BackgroundType",ui.cbBackgroundType->currentIndex());
@@ -946,12 +1024,13 @@ void WorksheetDock::saveConfigAsTemplate(KConfig& config) {
 	group.writeEntry("BackgroundOpacity", ui.sbBackgroundOpacity->value()/100.0);
 
 	//Layout
-	group.writeEntry("LayoutTopMargin",Worksheet::convertToSceneUnits(ui.sbLayoutTopMargin->value(), Worksheet::Centimeter));
-	group.writeEntry("LayoutBottomMargin",Worksheet::convertToSceneUnits(ui.sbLayoutBottomMargin->value(), Worksheet::Centimeter));
-	group.writeEntry("LayoutLeftMargin",Worksheet::convertToSceneUnits(ui.sbLayoutLeftMargin->value(), Worksheet::Centimeter));
-	group.writeEntry("LayoutRightMargin",Worksheet::convertToSceneUnits(ui.sbLayoutRightMargin->value(), Worksheet::Centimeter));
-	group.writeEntry("LayoutVerticalSpacing",Worksheet::convertToSceneUnits(ui.sbLayoutVerticalSpacing->value(), Worksheet::Centimeter));
-	group.writeEntry("LayoutHorizontalSpacing",Worksheet::convertToSceneUnits(ui.sbLayoutHorizontalSpacing->value(), Worksheet::Centimeter));
+	group.writeEntry("Layout", ui.cbLayout->currentIndex());
+	group.writeEntry("LayoutTopMargin",Worksheet::convertToSceneUnits(ui.sbLayoutTopMargin->value(), m_worksheetUnit));
+	group.writeEntry("LayoutBottomMargin",Worksheet::convertToSceneUnits(ui.sbLayoutBottomMargin->value(), m_worksheetUnit));
+	group.writeEntry("LayoutLeftMargin",Worksheet::convertToSceneUnits(ui.sbLayoutLeftMargin->value(), m_worksheetUnit));
+	group.writeEntry("LayoutRightMargin",Worksheet::convertToSceneUnits(ui.sbLayoutRightMargin->value(), m_worksheetUnit));
+	group.writeEntry("LayoutVerticalSpacing",Worksheet::convertToSceneUnits(ui.sbLayoutVerticalSpacing->value(), m_worksheetUnit));
+	group.writeEntry("LayoutHorizontalSpacing",Worksheet::convertToSceneUnits(ui.sbLayoutHorizontalSpacing->value(), m_worksheetUnit));
 	group.writeEntry("LayoutRowCount", ui.sbLayoutRowCount->value());
 	group.writeEntry("LayoutColumnCount", ui.sbLayoutColumnCount->value());
 
