@@ -93,7 +93,7 @@ void XYEquationCurveDock::setupGeneral() {
 
 	uiGeneralTab.pbRecalculate->setIcon(QIcon::fromTheme("run-build"));
 
-	uiGeneralTab.teEquation2->setExpressionType(XYEquationCurve::Parametric);
+	uiGeneralTab.teEquation2->setExpressionType(XYEquationCurve::EquationType::Parametric);
 
 // 	uiGeneralTab.teEquation1->setMaximumHeight(uiGeneralTab.leName->sizeHint().height()*2);
 // 	uiGeneralTab.teEquation2->setMaximumHeight(uiGeneralTab.leName->sizeHint().height()*2);
@@ -125,6 +125,7 @@ void XYEquationCurveDock::setCurves(QList<XYCurve*> list) {
 	m_initializing = true;
 	m_curvesList = list;
 	m_curve = list.first();
+	m_aspect = list.first();
 	m_equationCurve = dynamic_cast<XYEquationCurve*>(m_curve);
 	Q_ASSERT(m_equationCurve);
 	m_aspectTreeModel =  new AspectTreeModel(m_curve->project());
@@ -159,8 +160,8 @@ void XYEquationCurveDock::initGeneralTab() {
 	const auto* equationCurve = dynamic_cast<const XYEquationCurve*>(m_curve);
 	Q_ASSERT(equationCurve);
 	const XYEquationCurve::EquationData& data = equationCurve->equationData();
-	uiGeneralTab.cbType->setCurrentIndex(data.type);
-	this->typeChanged(data.type);
+	uiGeneralTab.cbType->setCurrentIndex(static_cast<int>(data.type));
+	this->typeChanged(static_cast<int>(data.type));
 	uiGeneralTab.teEquation1->setText(data.expression1);
 	uiGeneralTab.teEquation2->setText(data.expression2);
 	uiGeneralTab.teMin->setText(data.min);
@@ -180,8 +181,8 @@ void XYEquationCurveDock::initGeneralTab() {
 //**** SLOTs for changes triggered in XYEquationCurveDock *****
 //*************************************************************
 void XYEquationCurveDock::typeChanged(int index) {
-	const auto type = XYEquationCurve::EquationType(index);
-	if (type == XYEquationCurve::Cartesian) {
+	const auto type{XYEquationCurve::EquationType(index)};
+	if (type == XYEquationCurve::EquationType::Cartesian) {
 		uiGeneralTab.lEquation1->setText("y=f(x)");
 		uiGeneralTab.lEquation2->hide();
 		uiGeneralTab.teEquation2->hide();
@@ -193,7 +194,7 @@ void XYEquationCurveDock::typeChanged(int index) {
 		uiGeneralTab.teMax->show();
 		uiGeneralTab.lMin->setText(i18n("x, min"));
 		uiGeneralTab.lMax->setText(i18n("x, max"));
-	} else if (type == XYEquationCurve::Polar) {
+	} else if (type == XYEquationCurve::EquationType::Polar) {
 		uiGeneralTab.lEquation1->setText(QString::fromUtf8("r(φ)"));
 		uiGeneralTab.lEquation2->hide();
 		uiGeneralTab.teEquation2->hide();
@@ -205,7 +206,7 @@ void XYEquationCurveDock::typeChanged(int index) {
 		uiGeneralTab.teMax->show();
 		uiGeneralTab.lMin->setText(i18n("φ, min"));
 		uiGeneralTab.lMax->setText(i18n("φ, max"));
-	} else if (type == XYEquationCurve::Parametric) {
+	} else if (type == XYEquationCurve::EquationType::Parametric) {
 		uiGeneralTab.lEquation1->setText("x=f(t)");
 		uiGeneralTab.lEquation2->setText("y=f(t)");
 		uiGeneralTab.lEquation2->show();
@@ -218,7 +219,7 @@ void XYEquationCurveDock::typeChanged(int index) {
 		uiGeneralTab.teMax->show();
 		uiGeneralTab.lMin->setText(i18n("t, min"));
 		uiGeneralTab.lMax->setText(i18n("t, max"));
-	} else if (type == XYEquationCurve::Implicit) {
+	} else if (type == XYEquationCurve::EquationType::Implicit) {
 		uiGeneralTab.lEquation1->setText("f(x,y)");
 		uiGeneralTab.lEquation2->hide();
 		uiGeneralTab.teEquation2->hide();
@@ -300,12 +301,12 @@ void XYEquationCurveDock::showFunctions() {
 
 void XYEquationCurveDock::insertFunction1(const QString& str) {
 	//TODO: not all functions have only one argument
-	const auto type = XYEquationCurve::EquationType(uiGeneralTab.cbType->currentIndex());
-	if (type == XYEquationCurve::Cartesian)
+	const auto type{XYEquationCurve::EquationType(uiGeneralTab.cbType->currentIndex())};
+	if (type == XYEquationCurve::EquationType::Cartesian)
 		uiGeneralTab.teEquation1->insertPlainText(str + "(x)");
-	else if (type == XYEquationCurve::Polar)
+	else if (type == XYEquationCurve::EquationType::Polar)
 		uiGeneralTab.teEquation1->insertPlainText(str + "(phi)");
-	else if (type == XYEquationCurve::Parametric)
+	else if (type == XYEquationCurve::EquationType::Parametric)
 		uiGeneralTab.teEquation1->insertPlainText(str + "(t)");
 }
 
@@ -329,7 +330,7 @@ void XYEquationCurveDock::enableRecalculate() const {
 	//check whether the formular expressions are correct
 	bool valid = false;
 	const auto type = XYEquationCurve::EquationType(uiGeneralTab.cbType->currentIndex());
-	if (type != XYEquationCurve::Parametric)
+	if (type != XYEquationCurve::EquationType::Parametric)
 		valid = uiGeneralTab.teEquation1->isValid();
 	else
 		valid = (uiGeneralTab.teEquation1->isValid() && uiGeneralTab.teEquation2->isValid());
@@ -357,7 +358,7 @@ void XYEquationCurveDock::curveDescriptionChanged(const AbstractAspect* aspect)
 
 void XYEquationCurveDock::curveEquationDataChanged(const XYEquationCurve::EquationData& data) {
 	m_initializing = true;
-	uiGeneralTab.cbType->setCurrentIndex(data.type);
+	uiGeneralTab.cbType->setCurrentIndex(static_cast<int>(data.type));
 	uiGeneralTab.teEquation1->setText(data.expression1);
 	uiGeneralTab.teEquation2->setText(data.expression2);
 	uiGeneralTab.teMin->setText(data.min);
