@@ -28,6 +28,7 @@
 
 #include "ExportWorksheetDialog.h"
 #include "ui_exportworksheetwidget.h"
+#include "kdefrontend/GuiTools.h"
 
 #include <QCompleter>
 #include <QDesktopWidget>
@@ -61,6 +62,9 @@ ExportWorksheetDialog::ExportWorksheetDialog(QWidget* parent) : QDialog(parent),
 
 	m_okButton = btnBox->button(QDialogButtonBox::Ok);
 	m_cancelButton = btnBox->button(QDialogButtonBox::Cancel);
+
+	m_cancelButton->setToolTip(i18n("Close this dialog without exporting."));
+
 	ui->leFileName->setCompleter(new QCompleter(new QDirModel, this));
 
 	ui->bOpen->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
@@ -70,6 +74,9 @@ ExportWorksheetDialog::ExportWorksheetDialog(QWidget* parent) : QDialog(parent),
 	ui->cbFormat->insertSeparator(3);
 	ui->cbFormat->addItem(QIcon::fromTheme(QLatin1String("image-x-generic")), QLatin1String("Portable Network Graphics (PNG)"));
 
+	ui->cbExportTo->addItem(i18n("File"));
+	ui->cbExportTo->addItem(i18n("Clipboard"));
+
 	ui->cbExportArea->addItem(i18n("Object's bounding box"));
 	ui->cbExportArea->addItem(i18n("Current selection"));
 	ui->cbExportArea->addItem(i18n("Complete worksheet"));
@@ -82,7 +89,10 @@ ExportWorksheetDialog::ExportWorksheetDialog(QWidget* parent) : QDialog(parent),
 	ui->cbResolution->addItem(QLatin1String("600"));
 	ui->cbResolution->setValidator(new QIntValidator(ui->cbResolution));
 
-	connect(ui->cbFormat, static_cast<void (QComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ExportWorksheetDialog::formatChanged );
+	connect(ui->cbFormat, static_cast<void (QComboBox::*)(int)>(&KComboBox::currentIndexChanged),
+			this, &ExportWorksheetDialog::formatChanged);
+	connect(ui->cbExportTo, static_cast<void (QComboBox::*)(int)>(&KComboBox::currentIndexChanged),
+			this, &ExportWorksheetDialog::exportToChanged);
 	connect(ui->bOpen, &QPushButton::clicked, this, &ExportWorksheetDialog::selectFile);
 	connect(ui->leFileName, &QLineEdit::textChanged, this, &ExportWorksheetDialog::fileNameChanged);
 	connect(m_showOptionsButton, &QPushButton::clicked, this, &ExportWorksheetDialog::toggleOptions);
@@ -94,6 +104,7 @@ ExportWorksheetDialog::ExportWorksheetDialog(QWidget* parent) : QDialog(parent),
 	//restore saved settings if available
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportWorksheetDialog");
 	ui->cbFormat->setCurrentIndex(conf.readEntry("Format", 0));
+	ui->cbExportTo->setCurrentIndex(conf.readEntry("ExportTo", 0));
 	ui->cbExportArea->setCurrentIndex(conf.readEntry("Area", 0));
 	ui->chkExportBackground->setChecked(conf.readEntry("Background", true));
 	ui->cbResolution->setCurrentIndex(conf.readEntry("Resolution", 0));
@@ -114,6 +125,7 @@ ExportWorksheetDialog::~ExportWorksheetDialog() {
 	//save current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportWorksheetDialog");
 	conf.writeEntry("Format", ui->cbFormat->currentIndex());
+	conf.writeEntry("ExportTo", ui->cbExportTo->currentIndex());
 	conf.writeEntry("Area", ui->cbExportArea->currentIndex());
 	conf.writeEntry("Background", ui->chkExportBackground->isChecked());
 	conf.writeEntry("Resolution", ui->cbResolution->currentIndex());
@@ -126,12 +138,17 @@ void ExportWorksheetDialog::setFileName(const QString& name) {
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportWorksheetDialog");
 	QString dir = conf.readEntry("LastDir", "");
 	if (dir.isEmpty()) dir = QDir::homePath();
-	ui->leFileName->setText(dir + QDir::separator() +  name);
-	this->formatChanged(ui->cbFormat->currentIndex());
+	ui->leFileName->setText(dir + QLatin1String("/") +  name);
+
+	formatChanged(ui->cbFormat->currentIndex());
+	exportToChanged(ui->cbExportTo->currentIndex());
 }
 
 QString ExportWorksheetDialog::path() const {
-	return ui->leFileName->text();
+	if (ui->cbExportTo->currentIndex() == 0)
+		return ui->leFileName->text();
+	else
+		return QString();
 }
 
 WorksheetView::ExportFormat ExportWorksheetDialog::exportFormat() const {
@@ -162,9 +179,8 @@ int ExportWorksheetDialog::exportResolution() const {
 void ExportWorksheetDialog::slotButtonClicked(QAbstractButton* button) {
 	if (button == m_okButton)
 		okClicked();
-	else if (button == m_cancelButton) {
+	else if (button == m_cancelButton)
 	    reject();
-	}
 }
 
 //SLOTS
@@ -176,15 +192,10 @@ void ExportWorksheetDialog::okClicked() {
 	}
 
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportWorksheetDialog");
-	conf.writeEntry("Format", ui->cbFormat->currentIndex());
-	conf.writeEntry("Area", ui->cbExportArea->currentIndex());
-	conf.writeEntry("Resolution", ui->cbResolution->currentIndex());
-
 	QString path = ui->leFileName->text();
 	if (!path.isEmpty()) {
 		QString dir = conf.readEntry("LastDir", "");
-		ui->leFileName->setText(path);
-		int pos = path.lastIndexOf(QDir::separator());
+		int pos = path.lastIndexOf(QLatin1String("/"));
 		if (pos != -1) {
 			QString newDir = path.left(pos);
 			if (newDir != dir)
@@ -228,10 +239,10 @@ void ExportWorksheetDialog::selectFile() {
 	if (!path.isEmpty()) {
 		ui->leFileName->setText(path);
 
-		int pos = path.lastIndexOf(QDir::separator());
+		int pos = path.lastIndexOf(QLatin1String("/"));
 		if (pos != -1) {
 			const QString newDir = path.left(pos);
-			if (newDir != dir)
+			if (newDir != dir && QDir(newDir).exists())
 				conf.writeEntry("LastDir", newDir);
 		}
 	}
@@ -262,6 +273,37 @@ void ExportWorksheetDialog::formatChanged(int index) {
 	ui->cbResolution->setVisible(visible);
 }
 
+/*!
+	called when the target destination (file or clipboard) format was changed.
+ */
+void ExportWorksheetDialog::exportToChanged(int index) {
+	bool toFile = (index == 0);
+	ui->lFileName->setVisible(toFile);
+	ui->leFileName->setVisible(toFile);
+	ui->bOpen->setVisible(toFile);
+
+	if (toFile)
+		m_okButton->setToolTip(i18n("Export to file and close the dialog."));
+	else
+		m_okButton->setToolTip(i18n("Export to clipboard and close the dialog."));
+}
+
 void ExportWorksheetDialog::fileNameChanged(const QString& name) {
-	m_okButton->setEnabled(!name.simplified().isEmpty());
+	if (name.simplified().isEmpty()) {
+		m_okButton->setEnabled(false);
+		return;
+	}
+	QString path = ui->leFileName->text();
+	int pos = path.lastIndexOf(QLatin1String("/"));
+	if (pos != -1) {
+		QString dir = path.left(pos);
+		bool invalid = !QDir(dir).exists();
+		GuiTools::highlight(ui->leFileName, invalid);
+		if (invalid) {
+			m_okButton->setEnabled(false);
+			return;
+		}
+	}
+
+	m_okButton->setEnabled(true);
 }
