@@ -30,9 +30,6 @@
 #include "backend/spreadsheet/Spreadsheet.h"
 
 void AsciiFilterTest::initTestCase() {
-	const QString currentDir = __FILE__;
-	m_dataDir = currentDir.left(currentDir.lastIndexOf(QDir::separator())) + QDir::separator() + QLatin1String("data") + QDir::separator();
-
 	// needed in order to have the signals triggered by SignallingUndoCommand, see LabPlot.cpp
 	//TODO: redesign/remove this
 	qRegisterMetaType<const AbstractAspect*>("const AbstractAspect*");
@@ -48,8 +45,8 @@ void AsciiFilterTest::testEmptyFileAppend() {
 
 	const int rowCount = spreadsheet.rowCount();
 	const int colCount = spreadsheet.columnCount();
-	const QString fileName = m_dataDir + "empty_file.txt";
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Append;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/empty_file.txt"));
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Append;
 
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
 
@@ -63,8 +60,8 @@ void AsciiFilterTest::testEmptyFilePrepend() {
 
 	const int rowCount = spreadsheet.rowCount();
 	const int colCount = spreadsheet.columnCount();
-	const QString fileName = m_dataDir + "empty_file.txt";
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Prepend;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/empty_file.txt"));
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Prepend;
 
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
 
@@ -78,8 +75,8 @@ void AsciiFilterTest::testEmptyFileReplace() {
 
 	const int rowCount = spreadsheet.rowCount();
 	const int colCount = spreadsheet.columnCount();
-	const QString fileName = m_dataDir + "empty_file.txt";
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/empty_file.txt"));
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
 
 	QCOMPARE(spreadsheet.rowCount(), rowCount);
@@ -89,9 +86,9 @@ void AsciiFilterTest::testEmptyFileReplace() {
 void AsciiFilterTest::testEmptyLines01() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "empty_lines_01.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/empty_lines_01.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(true);
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
@@ -103,9 +100,9 @@ void AsciiFilterTest::testEmptyLines01() {
 	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("y"));
 	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("values"));
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Integer);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
 
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
@@ -121,9 +118,9 @@ void AsciiFilterTest::testEmptyLines01() {
 void AsciiFilterTest::testSparseFile01() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "sparse_file_01.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/sparse_file_01.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setHeaderEnabled(true);
 	filter.setSimplifyWhitespacesEnabled(true);
@@ -136,9 +133,9 @@ void AsciiFilterTest::testSparseFile01() {
 	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("Col1"));
 	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("Col2"));
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Integer);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
 
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
@@ -156,9 +153,9 @@ void AsciiFilterTest::testSparseFile01() {
 void AsciiFilterTest::testSparseFile02() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "sparse_file_02.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/sparse_file_02.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setNaNValueToZero(false);
 	filter.setSimplifyWhitespacesEnabled(true);
@@ -173,9 +170,9 @@ void AsciiFilterTest::testSparseFile02() {
 	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("Col1"));
 	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("Col2"));
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
@@ -193,9 +190,9 @@ void AsciiFilterTest::testSparseFile02() {
 void AsciiFilterTest::testSparseFile03() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "sparse_file_03.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/sparse_file_03.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setNaNValueToZero(true);
 	filter.setSimplifyWhitespacesEnabled(true);
@@ -210,9 +207,9 @@ void AsciiFilterTest::testSparseFile03() {
 	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("Col1"));
 	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("Col2"));
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
@@ -236,9 +233,9 @@ void AsciiFilterTest::testSparseFile03() {
 void AsciiFilterTest::testHeader01() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "separator_semicolon.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames(QString());
@@ -251,9 +248,9 @@ void AsciiFilterTest::testHeader01() {
 void AsciiFilterTest::testHeader02() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "separator_semicolon.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(true);
 	filter.setVectorNames(QString());
@@ -271,9 +268,9 @@ void AsciiFilterTest::testHeader02() {
 void AsciiFilterTest::testHeader03() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "separator_semicolon.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames("x");
@@ -287,9 +284,9 @@ void AsciiFilterTest::testHeader03() {
 void AsciiFilterTest::testHeader04() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "separator_semicolon.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames("x");
@@ -303,9 +300,9 @@ void AsciiFilterTest::testHeader04() {
 void AsciiFilterTest::testHeader05() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "separator_semicolon.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames("x y");
@@ -320,9 +317,9 @@ void AsciiFilterTest::testHeader05() {
 void AsciiFilterTest::testHeader06() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "separator_semicolon.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(";");
 	filter.setHeaderEnabled(false);
 	filter.setVectorNames("x y z");
@@ -334,15 +331,98 @@ void AsciiFilterTest::testHeader06() {
 	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("y"));
 }
 
+/*!
+ * test with a file containing the header in the second line
+ * with a subsequent comment line without any comment character.
+ * this line shouldn't disturb the detection of numeric column modes.
+ */
+void AsciiFilterTest::testHeader07() {
+	Spreadsheet spreadsheet("test", false);
+	AsciiFilter filter;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/comment_header_comment.txt"));
+
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
+	filter.setSeparatingCharacter("TAB");
+	filter.setStartRow(2);
+	filter.setHeaderEnabled(true);
+	filter.readDataFromFile(fileName, &spreadsheet, mode);
+
+	//spreadsheet size
+	QCOMPARE(spreadsheet.columnCount(), 3);
+	QCOMPARE(spreadsheet.rowCount(), 4);
+
+	//column names
+	QCOMPARE(spreadsheet.column(0)->name(), QLatin1String("counter"));
+	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("t[min]"));
+	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("#1ch1"));
+
+	//data types
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+
+	//values
+	QCOMPARE(spreadsheet.column(0)->integerAt(0), 0);
+	QCOMPARE((bool)std::isnan(spreadsheet.column(1)->valueAt(0)), true);
+	QCOMPARE((bool)std::isnan(spreadsheet.column(2)->valueAt(0)), true);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(1), 1);
+	QCOMPARE(spreadsheet.column(1)->valueAt(1), 0.0513);
+	QCOMPARE(spreadsheet.column(2)->valueAt(1), 0.3448);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(2), 2);
+	QCOMPARE(spreadsheet.column(1)->valueAt(2), 0.1005);
+	QCOMPARE(spreadsheet.column(2)->valueAt(2), 0.3418);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(3), 3);
+	QCOMPARE(spreadsheet.column(1)->valueAt(3), 0.1516);
+	QCOMPARE(spreadsheet.column(2)->valueAt(3), 0.3433);
+}
+
+/*!
+ * the header contains spaces in the column names, values are tab separated.
+ * when using "auto" for the separator characters, the tab character has to
+ * be properly recognized and used.
+ */
+void AsciiFilterTest::testHeader08() {
+	Spreadsheet spreadsheet("test", false);
+	AsciiFilter filter;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_tab_with_header_with_spaces.txt"));
+
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
+	filter.setSeparatingCharacter("auto");
+	filter.setHeaderEnabled(true);
+	filter.readDataFromFile(fileName, &spreadsheet, mode);
+
+	//spreadsheet size
+	QCOMPARE(spreadsheet.columnCount(), 2);
+	QCOMPARE(spreadsheet.rowCount(), 2);
+
+	//column names
+	QCOMPARE(spreadsheet.column(0)->name(), QLatin1String("first column"));
+	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("second column"));
+
+	//data types
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
+
+	//values
+	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
+	QCOMPARE(spreadsheet.column(1)->integerAt(0), 2);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(1), 3);
+	QCOMPARE(spreadsheet.column(1)->integerAt(1), 4);
+}
+
 //##############################################################################
 //#####################  handling of different read ranges #####################
 //##############################################################################
 void AsciiFilterTest::testColumnRange00() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
@@ -351,9 +431,9 @@ void AsciiFilterTest::testColumnRange00() {
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), 1.716299);
@@ -364,9 +444,9 @@ void AsciiFilterTest::testColumnRange00() {
 void AsciiFilterTest::testColumnRange01() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setCreateIndexEnabled(true);
@@ -376,10 +456,10 @@ void AsciiFilterTest::testColumnRange01() {
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 4);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
@@ -391,9 +471,9 @@ void AsciiFilterTest::testColumnRange01() {
 void AsciiFilterTest::testColumnRange02() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartColumn(2);
@@ -404,8 +484,8 @@ void AsciiFilterTest::testColumnRange02() {
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 2);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), -0.485527);
@@ -415,9 +495,9 @@ void AsciiFilterTest::testColumnRange02() {
 void AsciiFilterTest::testColumnRange03() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setCreateIndexEnabled(true);
@@ -429,9 +509,9 @@ void AsciiFilterTest::testColumnRange03() {
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
@@ -442,9 +522,9 @@ void AsciiFilterTest::testColumnRange03() {
 void AsciiFilterTest::testColumnRange04() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartColumn(3);
@@ -455,7 +535,7 @@ void AsciiFilterTest::testColumnRange04() {
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 1);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//check the values for the first line
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), -0.288690);
@@ -464,9 +544,9 @@ void AsciiFilterTest::testColumnRange04() {
 void AsciiFilterTest::testColumnRange05() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartColumn(3);
@@ -482,9 +562,9 @@ void AsciiFilterTest::testColumnRange05() {
 void AsciiFilterTest::testColumnRange06() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setCreateIndexEnabled(true);
@@ -496,16 +576,16 @@ void AsciiFilterTest::testColumnRange06() {
 	QCOMPARE(spreadsheet.rowCount(), 5);
 	QCOMPARE(spreadsheet.columnCount(), 1);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 }
 
 void AsciiFilterTest::testRowRange00() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartRow(3);
@@ -516,9 +596,9 @@ void AsciiFilterTest::testRowRange00() {
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//check the values for the first and for the last lines
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), 1.711721);
@@ -533,9 +613,9 @@ void AsciiFilterTest::testRowRange00() {
 void AsciiFilterTest::testRowRange01() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartRow(3);
@@ -546,9 +626,9 @@ void AsciiFilterTest::testRowRange01() {
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 3);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//check the values for the first and for the last lines
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), 1.711721);
@@ -563,9 +643,9 @@ void AsciiFilterTest::testRowRange01() {
 void AsciiFilterTest::testRowRange02() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartRow(3);
@@ -583,9 +663,9 @@ void AsciiFilterTest::testRowRange02() {
 void AsciiFilterTest::testRowColumnRange00() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "numeric_data.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/numeric_data.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter("auto");
 	filter.setHeaderEnabled(false);
 	filter.setStartRow(3);
@@ -598,8 +678,8 @@ void AsciiFilterTest::testRowColumnRange00() {
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 2);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Numeric);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//check the values for the first and for the last lines
 	QCOMPARE(spreadsheet.column(0)->valueAt(0), -0.485527);
@@ -620,9 +700,9 @@ void AsciiFilterTest::testRowColumnRange00() {
 void AsciiFilterTest::testQuotedStrings00() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "quoted_strings.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/quoted_strings.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setHeaderEnabled(false);
 	filter.setRemoveQuotesEnabled(true);
@@ -632,10 +712,10 @@ void AsciiFilterTest::testQuotedStrings00() {
 	QCOMPARE(spreadsheet.rowCount(), 3);
 	QCOMPARE(spreadsheet.columnCount(), 4);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Text);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Text);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	QCOMPARE(spreadsheet.column(0)->textAt(0), QLatin1String("a"));
 	QCOMPARE(spreadsheet.column(1)->integerAt(0), 1000);
@@ -656,9 +736,9 @@ void AsciiFilterTest::testQuotedStrings00() {
 void AsciiFilterTest::testQuotedStrings01() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "quoted_strings_with_header.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/quoted_strings_with_header.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setHeaderEnabled(true);
 	filter.setSimplifyWhitespacesEnabled(true);
@@ -676,10 +756,10 @@ void AsciiFilterTest::testQuotedStrings01() {
 	QCOMPARE(spreadsheet.column(3)->name(), QLatin1String("col4"));
 
 	//data types
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Text);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Text);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->textAt(0), QLatin1String("a"));
@@ -701,11 +781,11 @@ void AsciiFilterTest::testQuotedStrings01() {
 void AsciiFilterTest::testQuotedStrings02() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "quoted_strings_one_line.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/quoted_strings_one_line.txt"));
 
 	QCOMPARE(QFile::exists(fileName), true);
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setHeaderEnabled(false);
 	filter.setRemoveQuotesEnabled(true);
@@ -715,10 +795,10 @@ void AsciiFilterTest::testQuotedStrings02() {
 // 	QCOMPARE(spreadsheet.rowCount(), 1);
 // 	QCOMPARE(spreadsheet.columnCount(), 4);
 
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Text);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Text);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	QCOMPARE(spreadsheet.column(0)->textAt(0), QLatin1String("a"));
 	QCOMPARE(spreadsheet.column(1)->integerAt(0), 1000);
@@ -729,9 +809,9 @@ void AsciiFilterTest::testQuotedStrings02() {
 void AsciiFilterTest::testQuotedStrings03() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "quoted_strings_one_line_with_header.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/quoted_strings_one_line_with_header.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.setHeaderEnabled(true);
 	filter.setSimplifyWhitespacesEnabled(true);
@@ -749,10 +829,10 @@ void AsciiFilterTest::testQuotedStrings03() {
 	QCOMPARE(spreadsheet.column(3)->name(), QLatin1String("col4"));
 
 	//data types
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Text);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Text);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(2)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(3)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->textAt(0), QLatin1String("a"));
@@ -768,17 +848,17 @@ void AsciiFilterTest::testQuotedStrings03() {
 void AsciiFilterTest::testComments00() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "multi_line_comment.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/multi_line_comment.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
 
 	QCOMPARE(spreadsheet.columnCount(), 2);
 
 	//data types
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
@@ -791,17 +871,17 @@ void AsciiFilterTest::testComments00() {
 void AsciiFilterTest::testComments01() {
 	Spreadsheet spreadsheet("test", false);
 	AsciiFilter filter;
-	const QString fileName = m_dataDir + "multi_line_comment_with_empty_lines.txt";
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/multi_line_comment_with_empty_lines.txt"));
 
-	AbstractFileFilter::ImportMode mode = AbstractFileFilter::Replace;
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
 	filter.setSeparatingCharacter(",");
 	filter.readDataFromFile(fileName, &spreadsheet, mode);
 
 	QCOMPARE(spreadsheet.columnCount(), 2);
 
 	//data types
-	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::Integer);
-	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
 
 	//values
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
@@ -811,4 +891,83 @@ void AsciiFilterTest::testComments01() {
 	QCOMPARE(spreadsheet.column(1)->valueAt(1), 2.2);
 }
 
+/*!
+ * test with an empty comment character
+ */
+void AsciiFilterTest::testComments02() {
+	Spreadsheet spreadsheet("test", false);
+	AsciiFilter filter;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/separator_semicolon_with_header.txt"));
+
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
+	filter.setCommentCharacter("");
+	filter.setSeparatingCharacter(";");
+	filter.setHeaderEnabled(true);
+	filter.readDataFromFile(fileName, &spreadsheet, mode);
+
+	//spreadsheet size
+	QCOMPARE(spreadsheet.columnCount(), 2);
+	QCOMPARE(spreadsheet.rowCount(), 3);
+
+	//column names
+	QCOMPARE(spreadsheet.column(0)->name(), QLatin1String("c1"));
+	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("c2"));
+
+	//data types
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::Integer);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Integer);
+
+	//values
+	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
+	QCOMPARE(spreadsheet.column(1)->integerAt(0), 1);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
+	QCOMPARE(spreadsheet.column(1)->integerAt(1), 2);
+
+	QCOMPARE(spreadsheet.column(0)->integerAt(2), 3);
+	QCOMPARE(spreadsheet.column(1)->integerAt(2), 3);
+}
+
+
+//##############################################################################
+//#########################  handling of datetime data #########################
+//##############################################################################
+/*!
+ * read data containing only two characters for the year - 'yy'. The default year in
+ * QDateTime is 1900 . When reading such two-characters DateTime values we want
+ * to have the current centure after the import.
+ */
+void AsciiFilterTest::testDateTime00() {
+	Spreadsheet spreadsheet("test", false);
+	AsciiFilter filter;
+	const QString& fileName = QFINDTESTDATA(QLatin1String("data/datetime_01.csv"));
+
+	AbstractFileFilter::ImportMode mode = AbstractFileFilter::ImportMode::Replace;
+	filter.setSeparatingCharacter(",");
+	filter.setHeaderEnabled(true);
+	filter.setDateTimeFormat(QLatin1String("dd/MM/yy hh:mm:ss"));
+	filter.readDataFromFile(fileName, &spreadsheet, mode);
+
+	//spreadsheet size
+	QCOMPARE(spreadsheet.columnCount(), 2);
+	QCOMPARE(spreadsheet.rowCount(), 2);
+
+	//column names
+	QCOMPARE(spreadsheet.column(0)->name(), QLatin1String("Date"));
+	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("Water Pressure"));
+
+	//data types
+	QCOMPARE(spreadsheet.column(0)->columnMode(), AbstractColumn::ColumnMode::DateTime);
+	QCOMPARE(spreadsheet.column(1)->columnMode(), AbstractColumn::ColumnMode::Numeric);
+
+	//values
+	QDateTime value = QDateTime::fromString(QLatin1String("01/01/2019 00:00:00"), QLatin1String("dd/MM/yyyy hh:mm:ss"));
+	QCOMPARE(spreadsheet.column(0)->dateTimeAt(0), value);
+	QCOMPARE(spreadsheet.column(1)->valueAt(0), 14.7982);
+
+	value = QDateTime::fromString(QLatin1String("01/01/2019 00:00:00"), QLatin1String("dd/MM/yyyy hh:mm:ss"));
+	QCOMPARE(spreadsheet.column(0)->dateTimeAt(0), value);
+	QCOMPARE(spreadsheet.column(1)->valueAt(1), 14.8026);
+}
+
 QTEST_MAIN(AsciiFilterTest)
